@@ -1,11 +1,16 @@
 #!/bin/sh
 echo "*** Sword build system generation"
 echo "*** Recreating libtool"
-libtoolize --force --copy;
+if test -z "$LTIZE"; then
+LTIZE="$AUTODIR""libtoolize"
+fi
+echo "$LTIZE"
+	$LTIZE --force --copy;
+
 ACLOCAL="$AUTODIR""aclocal"
 echo "*** Recreating aclocal.m4"
 echo "$ACLOCAL"
-	$ACLOCAL;
+	$ACLOCAL -I m4;
 
 echo "*** Recreating configure"
 AUTOCONF="$AUTODIR""autoconf"
@@ -15,4 +20,4 @@ AUTOHEAD="$AUTODIR""autoheader"
 	
 echo "*** Recreating the Makefile.in files"
 AUTOMAKE="$AUTODIR""automake"
-	$AUTOMAKE -ac --foreign;
+	$AUTOMAKE -a -c --foreign;
