@@ -2,7 +2,7 @@
  *
  *  swordorb-impl.cpp -	omniorb bindings
  *
- * $Id: swordorb-impl.cpp 3284 2014-12-03 06:13:54Z greg.hellings $
+ * $Id: swordorb-impl.cpp 3256 2014-09-15 20:03:26Z scribe $
  *
  * Copyright 2009-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -243,7 +243,7 @@ swordorb::StringList* swordorb_SWModule_i::getKeyChildren(){
 
 	sword::VerseKey *vkey = SWDYNAMIC_CAST(VerseKey, key);
 	if (vkey) {
-		retVal->length(8);
+		retVal->length(10);
 		SWBuf num;
 		num.appendFormatted("%d", vkey->getTestament());
 		(*retVal)[0] = CORBA::string_dup(num.c_str());
@@ -264,6 +264,8 @@ swordorb::StringList* swordorb_SWModule_i::getKeyChildren(){
 		(*retVal)[5] = CORBA::string_dup(num.c_str());
 		(*retVal)[6] = CORBA::string_dup(vkey->getBookName());
 		(*retVal)[7] = CORBA::string_dup(vkey->getOSISRef());
+		(*retVal)[8] = CORBA::string_dup(vkey->getShortText());
+		(*retVal)[9] = CORBA::string_dup(vkey->getBookAbbrev());
 	}
 	else {
 		TreeKeyIdx *tkey = SWDYNAMIC_CAST(TreeKeyIdx, key);
