@@ -2,7 +2,7 @@
  *
  *  InstallMgr.java -	
  *
- * $Id: InstallMgr.java 2833 2013-06-29 06:40:28Z chrislit $
+ * $Id: InstallMgr.java 3229 2014-05-09 09:32:36Z scribe $
  *
  * Copyright 2009-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -23,6 +23,11 @@
 package org.crosswire.android.sword;
 
 public class InstallMgr {
+	
+	public static interface InstallProgressReporter {
+		public void update(long totalBytes, long completedBytes);
+		public void preStatus(long totalBytes, long completedBytes, String message);
+	}
 
 	public native void reInit();
 
@@ -32,7 +37,8 @@ public class InstallMgr {
 	public native String []        getRemoteSources();
 	public native int              refreshRemoteSource(String sourceName);
 	public native SWMgr.ModInfo [] getRemoteModInfoList(String sourceName);
-	public native int              remoteInstallModule(String sourceName, String modName);
+	public native int              remoteInstallModule(String sourceName, String modName, InstallProgressReporter progressReporter);
+	public int                     remoteInstallModule(String sourceName, String modName) { return remoteInstallModule(sourceName, modName, null); }
 	public native SWModule         getRemoteModuleByName(String source, String name);
 
 }
