@@ -2,7 +2,7 @@
  *
  *  SWModule.java -	
  *
- * $Id: SWModule.java 2833 2013-06-29 06:40:28Z chrislit $
+ * $Id: SWModule.java 3237 2014-05-22 08:02:06Z scribe $
  *
  * Copyright 2009-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -38,6 +38,17 @@ public class SWModule {
 	public static final int SEARCHTYPE_ENTRYATTR = -3;
 	public static final int SEARCHTYPE_LUCENE    = -4;
 
+	public static final int VERSEKEY_TESTAMENT  = 0;
+	public static final int VERSEKEY_BOOK       = 1;
+	public static final int VERSEKEY_CHAPTER    = 2;
+	public static final int VERSEKEY_VERSE      = 3;
+	public static final int VERSEKEY_CHAPTERMAX = 4;
+	public static final int VERSEKEY_VERSEMAX   = 5;
+	public static final int VERSEKEY_BOOKNAME   = 6;
+	public static final int VERSEKEY_OSISREF    = 7;
+	public static final int VERSEKEY_SHORTTEXT  = 8;
+	public static final int VERSEKEY_BOOKABBREV = 9;
+
 	private SWModule() {}	// don't allow allocation, instead use factory method SWMgr.getModuleByName to retrieve an instance
 
 	public static class SearchHit {
@@ -78,6 +89,7 @@ public class SWModule {
 	public native void          next();
 	public native void          begin();
 	public native String        getStripText();
+	public native String        getRenderHeader();
 	public native String        getRenderText();
 	public native String        getRawEntry();
 	public native void          setRawEntry(String entryBuffer);
