@@ -16,8 +16,6 @@
 
 #ifdef __cplusplus
 #include <rawfiles.h>
-class sword::RawFiles;
-class sword::SWConfig;
 #endif
 
 
