@@ -11,10 +11,9 @@
 	General Public License for more details. (http://www.gnu.org/licenses/gpl.html)
 */
 
-#import <Cocoa/Cocoa.h>
-#import "SwordModule.h"
+#import <Foundation/Foundation.h>
 
-@class SwordManager;
+@class SwordManager, SwordModule;
 
 @interface SwordDictionary : SwordModule {
     /** only keys are buffered here */
@@ -24,5 +23,4 @@
 - (NSArray *)allKeys;
 - (NSString *)entryForKey:(NSString *)aKey;
 
-
 @end
