@@ -18,56 +18,30 @@
 #import "SwordVerseKey.h"
 #import "SwordBible.h"
 #import "SwordCommentary.h"
-#import "SwordDictionary.h"
-#import "SwordBook.h"
-#import "SwordFilter.h"
+#import "SwordUtil.h"
 
 @interface SwordModule ()
 
-@property (retain, readwrite) NSString *name;
-@property (retain, readwrite) NSString *typeString;
-@property (retain, readwrite) NSString *descr;
-@property (retain, readwrite) NSString *lang;
-@property(readwrite, retain) NSMutableDictionary *configEntries;
-
-- (void)mainInit;
-
 @end
 
 @implementation SwordModule
 
-@synthesize configEntries;
-@synthesize type;
-@synthesize status;
-@synthesize moduleLock;
-@synthesize indexLock;
-@synthesize swManager;
-@synthesize name;
-@synthesize typeString;
-@synthesize descr;
-@synthesize lang;
-
-
 + (id)moduleForSWModule:(sword::SWModule *)aModule {
-    return [[[SwordModule alloc] initWithSWModule:aModule] autorelease];
+    return [[SwordModule alloc] initWithSWModule:aModule];
 }
 
-+ (id)moduleForSWModule:(sword::SWModule *)aModule swordManager:(SwordManager *)aManager {
-    return [[[SwordModule alloc] initWithSWModule:aModule swordManager:aManager] autorelease];
-}
-
-+ (id)moduleForType:(ModuleType)aType swModule:(sword::SWModule *)swModule swordManager:(SwordManager *)aManager {
++ (id)moduleForType:(ModuleType)aType swModule:(sword::SWModule *)swModule {
     SwordModule *sm;
     if(aType == Bible) {
-        sm = [[[SwordBible alloc] initWithSWModule:swModule swordManager:aManager] autorelease];
+        sm = [[SwordBible alloc] initWithSWModule:swModule];
     } else if(aType == Commentary) {
-        sm = [[[SwordCommentary alloc] initWithSWModule:swModule swordManager:aManager] autorelease];
+        sm = [[SwordCommentary alloc] initWithSWModule:swModule];
     } else if(aType == Dictionary) {
-        sm = [[[SwordDictionary alloc] initWithSWModule:swModule swordManager:aManager] autorelease];
+        sm = [[SwordDictionary alloc] initWithSWModule:swModule];
     } else if(aType == Genbook) {
-        sm = [[[SwordBook alloc] initWithSWModule:swModule swordManager:aManager] autorelease];
+        sm = [[SwordBook alloc] initWithSWModule:swModule];
     } else {
-        sm = [[[SwordModule alloc] initWithSWModule:swModule swordManager:aManager] autorelease];
+        sm = [[SwordModule alloc] initWithSWModule:swModule];
     }
     
     return sm;
@@ -123,38 +97,17 @@
 
 - (void)mainInit {
     category = Unset;
-    self.name = [self retrieveName];
-    self.typeString = [self retrieveType];
-    self.descr = [self retrieveDescr];
-    self.lang = [self retrieveLang];
 
-    self.type = [SwordModule moduleTypeForModuleTypeString:self.typeString];
-    self.moduleLock = [[[NSRecursiveLock alloc] init] autorelease];
-    self.indexLock = [[[NSLock alloc] init] autorelease];
+    self.type = [SwordModule moduleTypeForModuleTypeString:[self typeString]];
+    self.moduleLock = [[NSRecursiveLock alloc] init];
+    self.indexLock = [[NSLock alloc] init];
     self.configEntries = [NSMutableDictionary dictionary];
 }
 
-- (id)initWithName:(NSString *)aName swordManager:(SwordManager *)aManager {
-    self = [super init];
-	if(self) {
-		swModule = [aManager getSWModuleWithName:aName];
-        self.swManager = aManager;
-        
-        [self mainInit];
-	}
-	
-	return self;
-}
-
 - (id)initWithSWModule:(sword::SWModule *)aModule {
-    return [self initWithSWModule:aModule swordManager:nil];
-}
-
-- (id)initWithSWModule:(sword::SWModule *)aModule swordManager:(SwordManager *)aManager {    
     self = [super init];
     if(self) {
         swModule = aModule;
-        self.swManager = aManager;
         
         [self mainInit];
     }
@@ -162,91 +115,75 @@
     return self;
 }
 
-- (void)finalize {    
-	[super finalize];
-}
-
-- (void)dealloc {
-    [self setConfigEntries:nil];
-    [self setSwManager:nil];
-    [self setModuleLock:nil];
-    [self setIndexLock:nil];
-    [self setName:nil];
-    [self setDescr:nil];
-    [self setTypeString:nil];
-    [self setLang:nil];
-
-    [super dealloc];
-}
-
 #pragma mark - Filters
 
 - (void)addRenderFilter:(SwordFilter *)aFilter {
-    swModule->AddRenderFilter([aFilter swFilter]);
+    swModule->removeRenderFilter([aFilter swFilter]);
+    swModule->addRenderFilter([aFilter swFilter]);
 }
 
 - (void)addStripFilter:(SwordFilter *)aFilter {
-    swModule->AddStripFilter([aFilter swFilter]);
+    swModule->addStripFilter([aFilter swFilter]);
 }
 
 #pragma mark - Module access semaphores
 
 - (void)lockModuleAccess {
-    [moduleLock lock];
+    [self.moduleLock lock];
 }
 
 - (void)unlockModuleAccess {
-    [moduleLock unlock];
+    [self.moduleLock unlock];
+}
+
+- (NSString *)name {
+    NSString *str = [NSString stringWithCString:swModule->getName() encoding:NSUTF8StringEncoding];
+    if(!str) {
+        str = [NSString stringWithCString:swModule->getName() encoding:NSISOLatin1StringEncoding];
+    }
+    return str;
+}
+
+- (NSString *)descr {
+    NSString *str = [NSString stringWithCString:swModule->getDescription() encoding:NSUTF8StringEncoding];
+    if(!str) {
+        str = [NSString stringWithCString:swModule->getDescription() encoding:NSISOLatin1StringEncoding];
+    }
+    return str;
+}
+
+- (NSString *)lang {
+    NSString *str = [NSString stringWithCString:swModule->getLanguage() encoding:NSUTF8StringEncoding];
+    if(!str) {
+        str = [NSString stringWithCString:swModule->getLanguage() encoding:NSISOLatin1StringEncoding];
+    }
+    return str;
+}
+
+- (NSString *)typeString {
+    NSString *str = [NSString stringWithCString:swModule->getType() encoding:NSUTF8StringEncoding];
+    if(!str) {
+        str = [NSString stringWithCString:swModule->getType() encoding:NSISOLatin1StringEncoding];
+    }
+    return str;
+}
+
+- (NSAttributedString *)fullAboutText {
+    return [[NSAttributedString alloc] initWithString:@""];
+}
+
+- (NSInteger)error {
+    return swModule->popError();
 }
 
 #pragma mark - Conf entries
 
-- (NSAttributedString *)fullAboutText {
-    return [[[NSAttributedString alloc] initWithString:@""] autorelease];
-}
-
-- (NSInteger)error {
-    return swModule->Error();
-}
-
-- (NSString *)retrieveName {
-    NSString *str = [NSString stringWithCString:swModule->Name() encoding:NSUTF8StringEncoding];
-    if(!str) {
-        str = [NSString stringWithCString:swModule->Name() encoding:NSISOLatin1StringEncoding];
-    }
-    return str;
-}
-
-- (NSString *)retrieveDescr {
-    NSString *str = [NSString stringWithCString:swModule->Description() encoding:NSUTF8StringEncoding];
-    if(!str) {
-        str = [NSString stringWithCString:swModule->Description() encoding:NSISOLatin1StringEncoding];
-    }
-    return str;
-}
-
-- (NSString *)retrieveLang {
-    NSString *str = [NSString stringWithCString:swModule->Lang() encoding:NSUTF8StringEncoding];
-    if(!str) {
-        str = [NSString stringWithCString:swModule->Lang() encoding:NSISOLatin1StringEncoding];
-    }
-    return str;
-}
-
-- (NSString *)retrieveType {
-    NSString *str = [NSString stringWithCString:swModule->Type() encoding:NSUTF8StringEncoding];
-    if(!str) {
-        str = [NSString stringWithCString:swModule->Type() encoding:NSISOLatin1StringEncoding];
-    }
-    return str;
-}
-
 - (NSString *)categoryString {
-    NSString *cat = [configEntries objectForKey:SWMOD_CONFENTRY_CATEGORY];
+    NSString *cat = self.configEntries[SWMOD_CONFENTRY_CATEGORY];
     if(cat == nil) {
         cat = [self configFileEntryForConfigKey:SWMOD_CONFENTRY_CATEGORY];
         if(cat != nil) {
-            [configEntries setObject:cat forKey:SWMOD_CONFENTRY_CATEGORY];
+            self.configEntries[SWMOD_CONFENTRY_CATEGORY] = cat;
         }
     }
     
@@ -261,11 +198,11 @@
 }
 
 - (NSString *)cipherKey {
-    NSString *cipherKey = [configEntries objectForKey:SWMOD_CONFENTRY_CIPHERKEY];
+    NSString *cipherKey = self.configEntries[SWMOD_CONFENTRY_CIPHERKEY];
     if(cipherKey == nil) {
         cipherKey = [self configFileEntryForConfigKey:SWMOD_CONFENTRY_CIPHERKEY];
         if(cipherKey != nil) {
-            [configEntries setObject:cipherKey forKey:SWMOD_CONFENTRY_CIPHERKEY];
+            self.configEntries[SWMOD_CONFENTRY_CIPHERKEY] = cipherKey;
         }
     }
     
@@ -273,11 +210,11 @@
 }
 
 - (NSString *)version {
-    NSString *version = [configEntries objectForKey:SWMOD_CONFENTRY_VERSION];
+    NSString *version = self.configEntries[SWMOD_CONFENTRY_VERSION];
     if(version == nil) {
         version = [self configFileEntryForConfigKey:SWMOD_CONFENTRY_VERSION];
         if(version != nil) {
-            [configEntries setObject:version forKey:SWMOD_CONFENTRY_VERSION];
+            self.configEntries[SWMOD_CONFENTRY_VERSION] = version;
         }
     }
     
@@ -285,11 +222,11 @@
 }
 
 - (NSString *)minVersion {
-    NSString *minVersion = [configEntries objectForKey:SWMOD_CONFENTRY_MINVERSION];
+    NSString *minVersion = self.configEntries[SWMOD_CONFENTRY_MINVERSION];
     if(minVersion == nil) {
         minVersion = [self configFileEntryForConfigKey:SWMOD_CONFENTRY_MINVERSION];
         if(minVersion != nil) {
-            [configEntries setObject:minVersion forKey:SWMOD_CONFENTRY_MINVERSION];
+            self.configEntries[SWMOD_CONFENTRY_MINVERSION] = minVersion;
         }
     }
     
@@ -298,7 +235,7 @@
 
 /** this might be RTF string  but the return value will be converted to UTF8 */
 - (NSString *)aboutText {
-    NSMutableString *aboutText = [configEntries objectForKey:SWMOD_CONFENTRY_ABOUT];
+    NSMutableString *aboutText = self.configEntries[SWMOD_CONFENTRY_ABOUT];
     if(aboutText == nil) {
         aboutText = [NSMutableString stringWithString:[self configFileEntryForConfigKey:SWMOD_CONFENTRY_ABOUT]];
         if(aboutText != nil) {
@@ -311,7 +248,7 @@
 			[aboutText replaceOccurrencesOfString:@"\\pard" withString:@"" options:0 range:NSMakeRange(0, [aboutText length])];
 			[aboutText replaceOccurrencesOfString:@"\\par" withString:@"\n" options:0 range:NSMakeRange(0, [aboutText length])];
             
-			NSMutableString *retStr = [[@"" mutableCopy] autorelease];
+			NSMutableString *retStr = [@"" mutableCopy];
 			for(NSUInteger i=0; i<[aboutText length]; i++) {
 				unichar c = [aboutText characterAtIndex:i];
                 
@@ -321,7 +258,7 @@
 						//we have an unicode character!
 						@try {
 							NSInteger unicodeChar = 0;
-							NSMutableString *unicodeCharString = [[@"" mutableCopy] autorelease];
+							NSMutableString *unicodeCharString = [@"" mutableCopy];
 							int j = 0;
 							BOOL negative = NO;
 							if ([aboutText characterAtIndex:(i+2)] == '-') {
@@ -336,7 +273,7 @@
 							unicodeChar = [unicodeCharString integerValue];
 							if (negative) unicodeChar = 65536 - unicodeChar;
 							i += j+2;
-							[retStr appendFormat:@"%C", unicodeChar];
+							[retStr appendFormat:@"%C", (unichar)unicodeChar];
 						}
 						@catch (NSException * e) {
 							[retStr appendFormat:@"%C", c];
@@ -354,7 +291,7 @@
         } else {
             aboutText = [NSMutableString string];
         }
-        [configEntries setObject:aboutText forKey:SWMOD_CONFENTRY_ABOUT];
+        self.configEntries[SWMOD_CONFENTRY_ABOUT] = aboutText;
     }
     
     return aboutText;    
@@ -367,11 +304,11 @@
 
 - (BOOL)isEditable {
     BOOL ret = NO;
-    NSString *editable = [configEntries objectForKey:SWMOD_CONFENTRY_EDITABLE];
+    NSString *editable = self.configEntries[SWMOD_CONFENTRY_EDITABLE];
     if(editable == nil) {
         editable = [self configFileEntryForConfigKey:SWMOD_CONFENTRY_EDITABLE];
         if(editable != nil) {
-            [configEntries setObject:editable forKey:SWMOD_CONFENTRY_EDITABLE];
+            self.configEntries[SWMOD_CONFENTRY_EDITABLE] = editable;
         }
     }
     
@@ -386,11 +323,11 @@
 
 - (BOOL)isRTL {
     BOOL ret = NO;
-    NSString *direction = [configEntries objectForKey:SWMOD_CONFENTRY_DIRECTION];
+    NSString *direction = self.configEntries[SWMOD_CONFENTRY_DIRECTION];
     if(direction == nil) {
         direction = [self configFileEntryForConfigKey:SWMOD_CONFENTRY_DIRECTION];
         if(direction != nil) {
-            [configEntries setObject:direction forKey:SWMOD_CONFENTRY_DIRECTION];
+            self.configEntries[SWMOD_CONFENTRY_DIRECTION] = direction;
         }
     }
     
@@ -423,7 +360,7 @@
     if(key != nil) {
         // check user defaults, that's where we store the entered keys
         NSDictionary *cipherKeys = [[NSUserDefaults standardUserDefaults] objectForKey:DefaultsModuleCipherKeysKey];
-        if([key length] == 0 && [[cipherKeys allKeys] containsObject:[self name]] == NO) {
+        if([key length] == 0 && ![[cipherKeys allKeys] containsObject:[self name]]) {
             locked = YES;
         }
     }
@@ -455,7 +392,7 @@
 - (NSString *)configFileEntryForConfigKey:(NSString *)entryKey {
 	NSString *result = nil;
     
-	[moduleLock lock];
+	[self.moduleLock lock];
     const char *entryStr = swModule->getConfigEntry([entryKey UTF8String]);
 	if(entryStr) {
 		result = [NSString stringWithUTF8String:entryStr];
@@ -463,29 +400,11 @@
             result = [NSString stringWithCString:entryStr encoding:NSISOLatin1StringEncoding];
         }
     }
-	[moduleLock unlock];
+	[self.moduleLock unlock];
 	
 	return result;
 }
 
-#pragma mark - Module unlocking
-
-- (BOOL)unlock:(NSString *)unlockKey {
-    
-	if (![self isEncrypted]) {
-		return NO;
-    }
-    
-    NSMutableDictionary	*cipherKeys = [NSMutableDictionary dictionaryWithDictionary:
-                                       [[NSUserDefaults standardUserDefaults] objectForKey:DefaultsModuleCipherKeysKey]];
-    [cipherKeys setObject:unlockKey forKey:[self name]];
-    [[NSUserDefaults standardUserDefaults] setObject:cipherKeys forKey:DefaultsModuleCipherKeysKey];
-    
-	[swManager setCipherKey:unlockKey forModuleNamed:[self name]];
-    
-	return YES;
-}
-
 #pragma mark - Module positioning
 
 - (void)incKeyPosition {
@@ -501,11 +420,12 @@
 }
 
 - (void)setSwordKey:(SwordKey *)aKey {
+    swModule->getKey()->setPersist(true);
     swModule->setKey([aKey swKey]);
 }
 
 - (SwordKey *)createKey {
-    sword::SWKey *sk = swModule->CreateKey();
+    sword::SWKey *sk = swModule->createKey();
     SwordKey *newKey = [SwordKey swordKeyWithSWKey:sk makeCopy:YES];
     delete sk;
     
@@ -529,25 +449,25 @@
 - (id)attributeValueForParsedLinkData:(NSDictionary *)data withTextRenderType:(TextPullType)textType {
     id ret = nil;
     
-    NSString *passage = [data objectForKey:ATTRTYPE_PASSAGE];
+    NSString *passage = data[ATTRTYPE_PASSAGE];
     if(passage) {
         passage = [[passage stringByReplacingOccurrencesOfString:@"+" withString:@" "] stringByReplacingPercentEscapesUsingEncoding:NSUTF8StringEncoding];
     } 
-    NSString *attrType = [data objectForKey:ATTRTYPE_TYPE];
+    NSString *attrType = data[ATTRTYPE_TYPE];
     if([attrType isEqualToString:@"n"]) {
         NSString *footnoteText = [self entryAttributeValueFootnoteOfType:attrType 
-                                                              indexValue:[data objectForKey:ATTRTYPE_VALUE] 
+                                                              indexValue:data[ATTRTYPE_VALUE]
                                                                   forKey:[SwordKey swordKeyWithRef:passage]];
         ret = footnoteText;
     } else if([attrType isEqualToString:@"x"] || [attrType isEqualToString:@"scriptRef"] || [attrType isEqualToString:@"scripRef"]) {
         NSString *key = @"";
         if([attrType isEqualToString:@"x"]) {
             key = [self entryAttributeValueFootnoteOfType:attrType
-                                               indexValue:[data objectForKey:ATTRTYPE_VALUE] 
+                                               indexValue:data[ATTRTYPE_VALUE]
                                                    forKey:[SwordKey swordKeyWithRef:passage]];            
         } else {
-            key = [[[data objectForKey:ATTRTYPE_VALUE] stringByReplacingOccurrencesOfString:@"+" 
-                                                                                 withString:@" "] stringByReplacingPercentEscapesUsingEncoding:NSUTF8StringEncoding];            
+            key = [[data[ATTRTYPE_VALUE] stringByReplacingOccurrencesOfString:@"+"
+                                                                   withString:@" "] stringByReplacingPercentEscapesUsingEncoding:NSUTF8StringEncoding];
         }
         if(textType == TextTypeRendered) {
             ret = [self renderedTextEntriesForRef:key];
@@ -560,7 +480,7 @@
 }
 
 - (void)setProcessEntryAttributes:(BOOL)flag {
-    swModule->processEntryAttributes(flag);
+    swModule->setProcessEntryAttributes(flag);
 }
 
 - (BOOL)processEntryAttributes {
@@ -586,7 +506,9 @@
 - (NSArray *)entryAttributeValuesLemma {
     NSMutableArray *array = [NSMutableArray array];
     
-    // parse entry attributes and look for Lemma (String's numbers)
+    swModule->stripText(); // force processing of key, if it hasn't been done already
+    
+    // parse entry attributes and look for Lemma (Strong's numbers)
     sword::AttributeTypeList::iterator words;
     sword::AttributeList::iterator word;
     sword::AttributeValue::iterator strongVal;
@@ -611,21 +533,28 @@
     return [NSArray arrayWithArray:array];
 }
 
+- (NSArray *)entryAttributeValuesLemmaNormalized {
+    NSArray *lemmas = [self entryAttributeValuesLemma];
+    // post process all codes and mormalize the number
+    // Hebrew keys should have 5 number digits
+    return [SwordUtil padStrongsNumbers:lemmas];
+}
+
 - (NSString *)entryAttributeValuePreverseForKey:(SwordKey *)aKey {
-    [moduleLock lock];
+    [self.moduleLock lock];
     [self setSwordKey:aKey];
-    swModule->RenderText(); // force processing of key
+    swModule->renderText(); // force processing of key
     NSString *value = [self entryAttributeValuePreverse];
-    [moduleLock unlock];
+    [self.moduleLock unlock];
     return value;
 }
 
 - (NSString *)entryAttributeValueFootnoteOfType:(NSString *)fnType indexValue:(NSString *)index forKey:(SwordKey *)aKey {
-    [moduleLock lock];
+    [self.moduleLock lock];
     [self setSwordKey:aKey];
-    swModule->RenderText(); // force processing of key
+    swModule->renderText(); // force processing of key
     NSString *value = [self entryAttributeValueFootnoteOfType:fnType indexValue:index];
-    [moduleLock unlock];
+    [self.moduleLock unlock];
     return value;
 }
 
@@ -638,36 +567,36 @@
 
 - (NSString *)renderedText {
     NSString *ret = @"";
-    ret = [NSString stringWithUTF8String:swModule->RenderText()];
+    ret = [NSString stringWithUTF8String:swModule->renderText()];
     if(!ret) {
-        ret = [NSString stringWithCString:swModule->RenderText() encoding:NSISOLatin1StringEncoding];
+        ret = [NSString stringWithCString:swModule->renderText() encoding:NSISOLatin1StringEncoding];
     }
     return ret;
 }
 
 - (NSString *)renderedTextFromString:(NSString *)aString {
     NSString *ret = @"";
-    ret = [NSString stringWithUTF8String:swModule->RenderText([aString UTF8String])];
+    ret = [NSString stringWithUTF8String:swModule->renderText([aString UTF8String])];
     if(!ret) {
-        ret = [NSString stringWithCString:swModule->RenderText([aString UTF8String]) encoding:NSISOLatin1StringEncoding];
+        ret = [NSString stringWithCString:swModule->renderText([aString UTF8String]) encoding:NSISOLatin1StringEncoding];
     }
     return ret;
 }
 
 - (NSString *)strippedText {
     NSString *ret = @"";
-    ret = [NSString stringWithUTF8String:swModule->StripText()];
+    ret = [NSString stringWithUTF8String:swModule->stripText()];
     if(!ret) {
-        ret = [NSString stringWithCString:swModule->StripText() encoding:NSISOLatin1StringEncoding];
+        ret = [NSString stringWithCString:swModule->stripText() encoding:NSISOLatin1StringEncoding];
     }
     return ret;
 }
 
 - (NSString *)strippedTextFromString:(NSString *)aString {
     NSString *ret = @"";
-    ret = [NSString stringWithUTF8String:swModule->RenderText([aString UTF8String])];
+    ret = [NSString stringWithUTF8String:swModule->renderText([aString UTF8String])];
     if(!ret) {
-        ret = [NSString stringWithCString:swModule->RenderText([aString UTF8String]) encoding:NSISOLatin1StringEncoding];
+        ret = [NSString stringWithCString:swModule->renderText([aString UTF8String]) encoding:NSISOLatin1StringEncoding];
     }
     return ret;
 }
@@ -680,11 +609,35 @@
     return [self textEntriesForReference:reference textType:TextTypeRendered];
 }
 
+- (NSArray *)textEntriesForReference:(NSString *)aReference textType:(TextPullType)textType {
+    NSArray *ret = nil;
+    
+    SwordModuleTextEntry *entry = [self textEntryForKey:[SwordKey swordKeyWithRef:aReference]
+                                               textType:textType];
+    if(entry) {
+        ret = @[entry];
+    }
+    
+    return ret;
+}
+
+- (SwordModuleTextEntry *)renderedTextEntryForRef:(NSString *)reference {
+    return [self textEntryForKeyString:reference textType:TextTypeRendered];
+}
+
+- (SwordModuleTextEntry *)strippedTextEntryForRef:(NSString *)reference {
+    return [self textEntryForKeyString:reference textType:TextTypeStripped];
+}
+
+- (SwordModuleTextEntry *)textEntryForKeyString:(NSString *)aKeyString textType:(TextPullType)aType {
+    return [self textEntryForKey:[SwordKey swordKeyWithRef:aKeyString] textType:aType];
+}
+
 - (SwordModuleTextEntry *)textEntryForKey:(SwordKey *)aKey textType:(TextPullType)aType {
     SwordModuleTextEntry *ret = nil;
     
     if(aKey) {
-        [moduleLock lock];
+        [self.moduleLock lock];
         [self setSwordKey:aKey];
         if(![self error]) {
             NSString *txt = @"";
@@ -700,28 +653,12 @@
                 ALog(@"Nil key");
             }
         }
-        [moduleLock unlock];
+        [self.moduleLock unlock];
     }
     
     return ret;
 }
 
-- (SwordModuleTextEntry *)textEntryForKeyString:(NSString *)aKeyString textType:(TextPullType)aType {
-    return [self textEntryForKey:[SwordKey swordKeyWithRef:aKeyString] textType:aType];
-}
-
-- (NSArray *)textEntriesForReference:(NSString *)aReference textType:(TextPullType)textType {
-    NSArray *ret = nil;
-    
-    SwordModuleTextEntry *entry = [self textEntryForKey:[SwordKey swordKeyWithRef:aReference] 
-                                               textType:textType];
-    if(entry) {
-        ret = [NSArray arrayWithObject:entry];
-    }
-    
-    return ret;    
-}
-
 - (void)writeEntry:(SwordModuleTextEntry *)anEntry {}
 
 - (long)entryCount {
