@@ -14,8 +14,8 @@
     NSArray *content;
 }
 
-@property (retain, readwrite) NSString *key;
-@property (retain, readwrite) NSArray *content;
+@property (strong, readwrite) NSString *key;
+@property (strong, readwrite) NSArray *content;
 
 - (id)initWithKey:(NSString *)aKey content:(NSArray *)aContent;
 
