@@ -6,7 +6,7 @@
 //  Copyright 2010 Software by MABE. All rights reserved.
 //
 
-#import <Cocoa/Cocoa.h>
+#import <Foundation/Foundation.h>
 
 /*
  To define your own configuration:
@@ -27,10 +27,11 @@
 @end
 
 @interface Configuration : NSObject <Configuration> {
-    
+    Configuration *impl;
 }
 
 + (Configuration *)config;
++ (Configuration *)configWithImpl:(id<Configuration>)configImpl;
 
 - (NSString *)osVersion;
 - (NSString *)bundleVersion;
@@ -39,6 +40,6 @@
 - (NSString *)tempFolder;
 - (NSString *)logFile;
 
-- (void)setClass:(Class<Configuration>)classImpl;
+- (void)setImpl:(id<Configuration>)configImpl;
 
 @end
