@@ -12,32 +12,32 @@
 @implementation SwordListKeyTest
 
 - (void)testContainsKey {
-    SwordListKey *lk = [SwordListKey listKeyWithRef:@"Gen 1:1-5"];
+    SwordListKey *lk = [SwordListKey listKeyWithRef:@"Gen 1:1-5" v11n:@"KJV"];
     SwordVerseKey *vk = [SwordVerseKey verseKeyWithRef:@"Gen 1:3"];
-    STAssertTrue([lk containsKey:vk], @"");
+    XCTAssertTrue([lk containsKey:vk], @"");
 }
 
 /*
 - (void)testNumberOfVerses {
-    SwordListKey *lk = [SwordListKey listKeyWithRef:@"gen 1:2-20"];
-    STAssertNotNil(lk, @"");
-    STAssertTrue(([lk numberOfVerses] == 19), @"");
+    SwordListKey *lk = [SwordListKey listKeyWithRef:@"gen 1:2-20" v11n:@"KJV"];
+    XCTAssertNotNil(lk, @"");
+    XCTAssertTrue(([lk numberOfVerses] == 19), @"");
 }
 */
 
 - (void)testVerseEnumeratorAllObjects {
-    SwordListKey *lk = [SwordListKey listKeyWithRef:@"gen 1:2-20"];
-    STAssertNotNil(lk, @"");
+    SwordListKey *lk = [SwordListKey listKeyWithRef:@"gen 1:2-20" v11n:@"KJV"];
+    XCTAssertNotNil(lk, @"");
     
     VerseEnumerator *ve = [lk verseEnumerator];
     NSArray *verseRefs = [ve allObjects];
-    STAssertNotNil(verseRefs, @"");
-    STAssertTrue(([verseRefs count] == 19), @"");
+    XCTAssertNotNil(verseRefs, @"");
+    XCTAssertTrue(([verseRefs count] == 19), @"");
 }
 
 - (void)testVerseEnumeratorNextObject {
-    SwordListKey *lk = [SwordListKey listKeyWithRef:@"gen 1:2-20"];
-    STAssertNotNil(lk, @"");
+    SwordListKey *lk = [SwordListKey listKeyWithRef:@"gen 1:2-20" v11n:@"KJV"];
+    XCTAssertNotNil(lk, @"");
     
     VerseEnumerator *ve = [lk verseEnumerator];
     int count = 0;
@@ -45,7 +45,7 @@
     while((ref = [ve nextObject])) {
         count++;
     }
-    STAssertTrue((count == 19), @"");
+    XCTAssertTrue((count == 19), @"");
 }
 
 @end
