@@ -3,7 +3,7 @@
  *  lookup.cpp -	Simple example of how to retrieve an entry from a
  *			SWORD module
  *
- * $Id: lookup.cpp 3187 2014-04-17 04:34:03Z greg.hellings $
+ * $Id: lookup.cpp 3483 2017-06-25 15:19:34Z scribe $
  *
  * Copyright 1997-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -29,6 +29,7 @@
 #include <swfilter.h>
 #include <markupfiltmgr.h>
 #include <versekey.h>
+//#include "../../bindings/corba/orbitcpp/webmgr.hpp"
 
 
 using sword::SWMgr;
@@ -36,7 +37,9 @@ using sword::MarkupFilterMgr;
 using sword::SWModule;
 using sword::FMT_WEBIF;
 using sword::FMT_HTMLHREF;
+using sword::FMT_XHTML;
 using sword::FMT_RTF;
+using sword::FMT_LATEX;
 using sword::ModMap;
 using sword::AttributeTypeList;
 using sword::AttributeList;
@@ -48,8 +51,13 @@ using sword::FilterList;
 int main(int argc, char **argv)
 {
 	
-	SWMgr manager(new MarkupFilterMgr(FMT_WEBIF));
-//	SWMgr manager(new MarkupFilterMgr(FMT_HTMLHREF));
+// for testing webmgr
+//	WebMgr manager((const char *)0);
+//	manager.setJavascript(true);
+//
+	SWMgr manager(new MarkupFilterMgr(FMT_XHTML));
+//	SWMgr manager(new MarkupFilterMgr(FMT_WEBIF));
+
 	SWModule *target;
 
 	if (argc != 3) {
@@ -71,7 +79,7 @@ int main(int argc, char **argv)
 
 	// turn all filters to default values
 	manager.setGlobalOption("Headings", "On");
-	manager.setGlobalOption("Strong's Numbers", "On");
+	manager.setGlobalOption("Strong's Numbers", "Off");
 	manager.setGlobalOption("Lemmas", "Off");
 //	manager.setGlobalOption("Greek Accents", "Off");
 
