@@ -1,8 +1,10 @@
 /***************************************************************************
  *
- * $Id: gbfredletterwords.h 1688 2005-01-01 04:42:26Z scribe $
+ *  gbfredletterwords.h -	Implementation of GBFRedLetterWords
  *
- * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
+ * $Id: gbfredletterwords.h 3451 2017-03-29 22:42:00Z scribe $
+ *
+ * Copyright 2003-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -18,7 +20,7 @@
  *
  */
 
-#ifndef GBFSREDLETTERWORDS_H
+#ifndef GBFREDLETTERWORDS_H
 #define GBFREDLETTERWORDS_H
 
 #include <swoptfilter.h>
