@@ -1,10 +1,11 @@
 /******************************************************************************
- *  swdisp.h  - code for base class 'swdisp'.  swdisp is the basis for all
+ *
+ *  swdisp.h -	code for base class 'swdisp'.  swdisp is the basis for all
  *		types of displays (e.g. raw textout, curses, xwindow, etc.)
  *
- * $Id: swdisp.h 1825 2005-06-10 09:03:37Z jansorg $
+ * $Id: swdisp.h 2833 2013-06-29 06:40:28Z chrislit $
  *
- * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
+ * Copyright 1996-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -36,7 +37,7 @@ class SWModule;
 class SWDLLEXPORT SWDisplay : public SWObject {
   static SWClass classdef;
 public:
-  SWDisplay () { myclass = &classdef; };
+  SWDisplay() { myclass = &classdef; };
   virtual ~SWDisplay() {};
   
   /** casts a module to a character pointer and displays it to
@@ -46,7 +47,8 @@ public:
   * @param imodule module to display
   * @return error status
   */
-  virtual char Display (SWModule & imodule);
+  virtual char display(SWModule &imodule) = 0;
+  SWDEPRECATED char Display(SWModule &imodule) { return display(imodule); }
 };
 
 SWORD_NAMESPACE_END
