@@ -1,3 +1,25 @@
+/******************************************************************************
+ *
+ *  sysdata.h -	
+ *
+ * $Id: sysdata.h 3455 2017-04-24 08:50:31Z scribe $
+ * 
+ * Copyright 2001-2013 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ */
+
 #ifndef SIZEDTYPES_H
 #define SIZEDTYPES_H
 /*
@@ -18,9 +40,16 @@ typedef unsigned short __u16;
 typedef signed int __s32;
 typedef unsigned int __u32;
 
-#if defined(__GNUC__) && !defined(__STRICT_ANSI__)
-//typedef __signed__ long long __s64;
-//typedef unsigned long long __u64;
+#ifdef OS_ANDROID
+#elif defined(__GNUC__)
+__extension__ typedef __signed__ long long __s64;
+__extension__ typedef unsigned long long __u64;
+#elif defined(__BORLANDC__)
+typedef signed __int64 __s64;
+typedef unsigned __int64 __u64;
+#else
+typedef signed long long __s64;
+typedef unsigned long long __u64;
 #endif
 
 #undef __swswap16
