@@ -2,7 +2,7 @@
  *
  *  teirtf.h -	Implementation of TEIRTF
  *
- * $Id: teirtf.h 2833 2013-06-29 06:40:28Z chrislit $
+ * $Id: teirtf.h 3548 2017-12-10 05:11:38Z scribe $
  *
  * Copyright 2006-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -35,7 +35,7 @@ private:
 protected:
 	class MyUserData : public BasicFilterUserData {
 	public:
-		bool BiblicalText;
+		bool isBiblicalText;
 		bool inOsisRef;
 		SWBuf w;
 		SWBuf version;
