@@ -1,8 +1,10 @@
 /******************************************************************************
  *
- * $Id: thmlhtmlhref.h 2157 2008-05-13 23:37:56Z scribe $
+ *  thmlhtmlhref.h -	Implementation of ThMLHTMLHREF
  *
- * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
+ * $Id: thmlhtmlhref.h 3548 2017-12-10 05:11:38Z scribe $
+ *
+ * Copyright 2001-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -30,13 +32,14 @@ SWORD_NAMESPACE_START
  */
 class SWDLLEXPORT ThMLHTMLHREF : public SWBasicFilter {
 	SWBuf imgPrefix;
+	bool renderNoteNumbers;
 protected:
 	class MyUserData : public BasicFilterUserData {
 	public:
 		MyUserData(const SWModule *module, const SWKey *key);//: BasicFilterUserData(module, key) {}
 		bool inscriptRef;
-		bool SecHead;
-		bool BiblicalText;
+		bool inSecHead;
+		bool isBiblicalText;
 		SWBuf version;
 		XMLTag startTag;
 	};
@@ -48,6 +51,7 @@ public:
 	ThMLHTMLHREF();
 	virtual const char *getImagePrefix() { return imgPrefix.c_str(); }
 	virtual void setImagePrefix(const char *newImgPrefix) { imgPrefix = newImgPrefix; }
+	void setRenderNoteNumbers(bool val = true) { renderNoteNumbers = val; }
 };
 SWORD_NAMESPACE_END
 #endif /* _THMLHTMLHREF_H */
