@@ -1,8 +1,10 @@
 /******************************************************************************
  *
- * $Id: thmlrtf.h 1688 2005-01-01 04:42:26Z scribe $
+ *  thmlrtf.h -	Implementation of ThMLRTF
  *
- * Copyright 1998 CrossWire Bible Society (http://www.crosswire.org)
+ * $Id: thmlrtf.h 3548 2017-12-10 05:11:38Z scribe $
+ *
+ * Copyright 1999-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -33,9 +35,9 @@ protected:
 	class MyUserData : public BasicFilterUserData {
 	public:
 		MyUserData(const SWModule *module, const SWKey *key);
-		bool SecHead;
+		bool inSecHead;
 		SWBuf version;
-		bool BiblicalText;
+		bool isBiblicalText;
 		XMLTag startTag;
 	};
 	virtual BasicFilterUserData *createUserData(const SWModule *module, const SWKey *key) {
