@@ -3,7 +3,7 @@
  *  xzcomprs.h -	XzCompress, a driver class that provides xz (LZMA2)
  *			compression
  *
- * $Id: xzcomprs.h 3156 2014-04-17 03:50:37Z greg.hellings $
+ * $Id: xzcomprs.h 3249 2014-08-24 01:55:08Z scribe $
  *
  * Copyright 2000-2014 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -27,6 +27,7 @@
 #include <swcomprs.h>
 
 #include <defs.h>
+#include <sysdata.h>
 
 SWORD_NAMESPACE_START
 
@@ -39,6 +40,9 @@ public:
 
 	virtual void Encode(void);
 	virtual void Decode(void);
+	virtual void setLevel(int l);
+private:
+	__u64 memlimit; // memory usage limit during decompression
 };
 
 SWORD_NAMESPACE_END
