@@ -1,10 +1,12 @@
 /******************************************************************************
- *  swkey.cpp - code for base class 'SWKey'.  SWKey is the basis for all
- *	        types of keys for indexing into modules (e.g. verse, word,
+ *
+ *  swkey.cpp -	code for base class 'SWKey'.  SWKey is the basis for all
+ *		types of keys for indexing into modules (e.g. verse, word,
  *		place, etc.)
  *
+ * $Id: swkey.cpp 2833 2013-06-29 06:40:28Z chrislit $
  *
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ * Copyright 1997-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -95,7 +97,7 @@ SWKey::~SWKey() {
  * RET:	value of persist
  */
 
-char SWKey::Persist() const
+bool SWKey::isPersist() const
 {
 	return persist;
 }
@@ -126,20 +128,14 @@ SWLocale *SWKey::getPrivateLocale() const {
 /******************************************************************************
  * SWKey::Persist - Set/gets whether this object itself persists within a
  *			module that it was used to setKey or just a copy.
- *			(1 - persists in module; 0 - a copy is attempted
+ *			(true - persists in module; false - a copy is attempted
  *
  * ENT:	ipersist - value which to set persist
- *		[-1] - only get
- *
- * RET:	value of persist
  */
 
-char SWKey::Persist(signed char ipersist)
+void SWKey::setPersist(bool ipersist)
 {
-	if (ipersist != -1)
-		persist = ipersist;
-
-	return persist;
+	persist = ipersist;
 }
 
 
@@ -149,7 +145,7 @@ char SWKey::Persist(signed char ipersist)
  * RET:	error status
  */
 
-char SWKey::Error()
+char SWKey::popError()
 {
 	char retval = error;
 
