@@ -2,7 +2,7 @@
  *
  *  curlftpt.cpp -	CURLFTPTransport
  *
- * $Id: curlftpt.cpp 2980 2013-09-14 21:51:47Z scribe $
+ * $Id: curlftpt.cpp 3439 2016-10-23 08:32:02Z scribe $
  *
  * Copyright 2004-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -63,12 +63,12 @@ namespace {
 				return -1; /* failure, can't open file to write */
 		}
 		if (out->destBuf) {
-			int s = out->destBuf->size();
+			int s = (int)out->destBuf->size();
 			out->destBuf->size(s+(size*nmemb));
 			memcpy(out->destBuf->getRawData()+s, buffer, size*nmemb);
-			return nmemb;
+			return (int)nmemb;
 		}
-		return fwrite(buffer, size, nmemb, out->stream);
+		return (int)fwrite(buffer, size, nmemb, out->stream);
 	}
 
 
