@@ -3,7 +3,7 @@
  *  filemgr.cpp -	implementation of class FileMgr used for pooling file
  *			handles
  *
- * $Id: filemgr.cpp 2833 2013-06-29 06:40:28Z chrislit $
+ * $Id: filemgr.cpp 3515 2017-11-01 11:38:09Z scribe $
  *
  * Copyright 1998-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -24,6 +24,7 @@
 #include <filemgr.h>
 #include <utilstr.h>
 
+#include <stdlib.h>
 #include <dirent.h>
 #include <fcntl.h>
 #include <sys/stat.h>
@@ -131,15 +132,6 @@ FileDesc::~FileDesc() {
 }
 
 
-int FileDesc::getFd() {
-	if (fd == -77)
-		fd = parent->sysOpen(this);
-//	if ((fd < -1) && (fd != -77))  // kludge to hand ce
-//		return 777;
-	return fd;
-}
-
-
 long FileDesc::seek(long offset, int whence) {
 	return lseek(getFd(), offset, whence);
 }
@@ -282,8 +274,8 @@ signed char FileMgr::trunc(FileDesc *file) {
 	
 		file->seek(0, SEEK_SET);
 		while (size > 0) {	 
-			bytes = file->read(nibble, 32767);
-			bytes = (bytes < size)?bytes:size;
+			bytes = (int)file->read(nibble, 32767);
+			bytes = (bytes < size)?bytes:(int)size;
 			if (write(fd, nibble, bytes) != bytes) { break; }
 			size -= bytes;
 		}
@@ -296,7 +288,7 @@ signed char FileMgr::trunc(FileDesc *file) {
 			// copy tmp file back (dumb, but must preserve file permissions)
 			lseek(fd, 0, SEEK_SET);
 			do {
-				bytes = read(fd, nibble, 32767);
+				bytes = (int)read(fd, nibble, 32767);
 				file->write(nibble, bytes);
 			} while (bytes == 32767);
 		}
@@ -316,7 +308,7 @@ signed char FileMgr::trunc(FileDesc *file) {
 
 signed char FileMgr::existsFile(const char *ipath, const char *ifileName)
 {
-	int len = strlen(ipath) + ((ifileName)?strlen(ifileName):0) + 3;
+	int len = (int)strlen(ipath) + ((ifileName)?strlen(ifileName):0) + 3;
 	char *ch;
 	char *path = new char [ len ];
 	strcpy(path, ipath);
@@ -337,7 +329,7 @@ signed char FileMgr::existsFile(const char *ipath, const char *ifileName)
 signed char FileMgr::existsDir(const char *ipath, const char *idirName)
 {
 	char *ch;
-	int len = strlen(ipath) + ((idirName)?strlen(idirName):0) + 1;
+	int len = (int)strlen(ipath) + ((idirName)?strlen(idirName):0) + 1;
 	if (idirName)
 		len +=  strlen(idirName);
 	char *path = new char [ len ];
@@ -361,7 +353,7 @@ int FileMgr::createParent(const char *pName) {
 	int retCode = 0;
 	
 	strcpy(buf, pName);
-	int end = strlen(buf) - 1;
+	int end = (int)strlen(buf) - 1;
 	while (end) {
 		if ((buf[end] == '/') || (buf[end] == '\\'))
 			break;
@@ -418,7 +410,7 @@ int FileMgr::copyFile(const char *sourceFile, const char *targetFile) {
 		return -1;
 
 	do {
-		len = read(sfd, buf, 4096);
+		len = (int)read(sfd, buf, 4096);
 		if (write(dfd, buf, len) != len) break;
 	}
 	while(len == 4096);	
@@ -447,7 +439,7 @@ char FileMgr::getLine(FileDesc *fDesc, SWBuf &line) {
 	while (more) {
 		more = false;
 		long index = fDesc->seek(0, SEEK_CUR);
-		len = fDesc->read(chunk, 254);
+		len = (int)fDesc->read(chunk, 254);
 
 		// assert we have a readable file (not a directory)
 		if (len < 1)
@@ -509,23 +501,24 @@ char FileMgr::isDirectory(const char *path) {
 int FileMgr::copyDir(const char *srcDir, const char *destDir) {
 	DIR *dir;
 	struct dirent *ent;
+	int retVal = 0;
 	if ((dir = opendir(srcDir))) {
 		rewinddir(dir);
-		while ((ent = readdir(dir))) {
+		while ((ent = readdir(dir)) && !retVal) {
 			if ((strcmp(ent->d_name, ".")) && (strcmp(ent->d_name, ".."))) {
 				SWBuf srcPath  = (SWBuf)srcDir  + (SWBuf)"/" + ent->d_name;
 				SWBuf destPath = (SWBuf)destDir + (SWBuf)"/" + ent->d_name;
 				if (!isDirectory(srcPath.c_str())) {
-					copyFile(srcPath.c_str(), destPath.c_str());
+					retVal = copyFile(srcPath.c_str(), destPath.c_str());
 				}
 				else {
-					copyDir(srcPath.c_str(), destPath.c_str());
+					retVal = copyDir(srcPath.c_str(), destPath.c_str());
 				}
 			}
 		}
 		closedir(dir);
 	}
-	return 0;
+	return retVal;
 }
 
 
@@ -582,4 +575,22 @@ long FileMgr::resourceConsumption() {
 }
 
 
+SWBuf FileMgr::getHomeDir() {
+
+	// figure out 'home' directory for app data
+	SWBuf homeDir = getenv("HOME");
+	if (!homeDir.length()) {
+		// silly windows
+		homeDir = getenv("APPDATA");
+	}
+	if (homeDir.length()) {
+		if ((homeDir[homeDir.length()-1] != '\\') && (homeDir[homeDir.length()-1] != '/')) {
+			homeDir += "/";
+		}
+	}
+
+	return homeDir;
+}
+
+
 SWORD_NAMESPACE_END
