@@ -3,7 +3,7 @@
  *  localemgr.cpp -	implementation of class LocaleMgr used to interact with
  *			registered locales for a SWORD installation
  *
- * $Id: localemgr.cpp 3005 2014-01-09 04:06:11Z greg.hellings $
+ * $Id: localemgr.cpp 3515 2017-11-01 11:38:09Z scribe $
  *
  * Copyright 2000-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -85,7 +85,7 @@ LocaleMgr::LocaleMgr(const char *iConfigPath) {
 		SWLog::getSystemLog()->logDebug("LOOKING UP LOCALE DIRECTORY...");
 		SWMgr::findConfig(&configType, &prefixPath, &configPath, &augPaths, &sysConf);
 		if (sysConf) {
-			if ((entry = sysConf->Sections["Install"].find("LocalePath")) != sysConf->Sections["Install"].end()) {
+			if ((entry = sysConf->getSection("Install").find("LocalePath")) != sysConf->getSection("Install").end()) {
 				configType = 9;	// our own
 				stdstr(&prefixPath, (char *)entry->second.c_str());
 				SWLog::getSystemLog()->logDebug("LocalePath provided in sysConfig.");
@@ -101,7 +101,7 @@ LocaleMgr::LocaleMgr(const char *iConfigPath) {
 		switch (configType) {
 		case 2:
 			int i;
-			for (i = strlen(configPath)-1; ((i) && (configPath[i] != '/') && (configPath[i] != '\\')); i--);
+			for (i = (int)strlen(configPath)-1; ((i) && (configPath[i] != '/') && (configPath[i] != '\\')); i--);
 			configPath[i] = 0;
 			path = configPath;
 			path += "/";
