@@ -2,7 +2,7 @@
  *
  *  stringmgr.cpp -	implementation of class StringMgr
  *
- * $Id: stringmgr.cpp 2980 2013-09-14 21:51:47Z scribe $
+ * $Id: stringmgr.cpp 3439 2016-10-23 08:32:02Z scribe $
  *
  * Copyright 2004-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -248,7 +248,7 @@ bool StringMgr::supportsUnicode() const {
 
 char *ICUStringMgr::upperUTF8(char *buf, unsigned int maxlen) const {
 	char *ret = buf;
-	int max = (maxlen) ? maxlen : strlen(buf);
+	int max = (int)((maxlen) ? maxlen : strlen(buf));
 		
 	UErrorCode err = U_ZERO_ERROR;
 		
