@@ -2,7 +2,7 @@
  *
  *  entriesblk.cpp -	EntriesBlock facilitates compressed lex/dict modules
  *
- * $Id: entriesblk.cpp 2833 2013-06-29 06:40:28Z chrislit $
+ * $Id: entriesblk.cpp 3439 2016-10-23 08:32:02Z scribe $
  *
  * Copyright 2001-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -84,8 +84,8 @@ void EntriesBlock::getMetaEntry(int index, unsigned long *offset, unsigned long
 
 
 void EntriesBlock::setMetaEntry(int index, unsigned long offset, unsigned long size) {
-	__u32 rawOffset = archtosword32(offset);
-	__u32 rawSize = archtosword32(size);
+	__u32 rawOffset = (__u32)archtosword32(offset);
+	__u32 rawSize = (__u32)archtosword32(size);
 
 	if (index >= getCount())	// assert index < count
 		return;
