@@ -5,7 +5,7 @@
  *			and provides lookup and parsing functions based on
  *			class VerseKey
  *
- * $Id: rawverse.cpp 3181 2014-04-17 04:27:57Z greg.hellings $
+ * $Id: rawverse.cpp 3439 2016-10-23 08:32:02Z scribe $
  *
  * Copyright 1997-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -186,7 +186,7 @@ void RawVerse::doSetText(char testmt, long idxoff, const char *buf, long len)
 
 	size = (len < 0) ? strlen(buf) : len;
 
-	start = textfp[testmt-1]->seek(0, SEEK_END);
+	start = (__s32)textfp[testmt-1]->seek(0, SEEK_END);
 	idxfp[testmt-1]->seek(idxoff, SEEK_SET);
 
 	if (size) {
