@@ -6,7 +6,7 @@
  *			and provides lookup and parsing functions based on
  *			class VerseKey
  *
- * $Id: rawverse4.cpp 3182 2014-04-17 04:28:36Z greg.hellings $
+ * $Id: rawverse4.cpp 3439 2016-10-23 08:32:02Z scribe $
  *
  * Copyright 2007-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -185,9 +185,9 @@ void RawVerse4::doSetText(char testmt, long idxoff, const char *buf, long len)
 	if (!testmt)
 		testmt = ((idxfp[1]) ? 1:2);
 
-	size = (len < 0) ? strlen(buf) : len;
+	size = (__u32)((len < 0) ? strlen(buf) : len);
 
-	start = textfp[testmt-1]->seek(0, SEEK_END);
+	start = (__u32)textfp[testmt-1]->seek(0, SEEK_END);
 	idxfp[testmt-1]->seek(idxoff, SEEK_SET);
 
 	if (size) {
