@@ -5,7 +5,7 @@
  *			and provides lookup and parsing functions based on
  *			class VerseKey for compressed modules
  *
- * $Id: zverse.cpp 2833 2013-06-29 06:40:28Z chrislit $
+ * $Id: zverse.cpp 3439 2016-10-23 08:32:02Z scribe $
  *
  * Copyright 1996-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -67,7 +67,6 @@ zVerse::zVerse(const char *ipath, int fileMode, int blockType, SWCompress *icomp
 
 	SWBuf buf;
 
-	nl = '\n';
 	path = 0;
 	cacheBufIdx = -1;
 	cacheTestament = 0;
@@ -273,7 +272,7 @@ void zVerse::zReadText(char testmt, long start, unsigned short size, unsigned lo
 		compressor->Buf(0, &len);
 		cacheBuf = (char *)calloc(len + 1, 1);
 		memcpy(cacheBuf, compressor->Buf(), len);
-		cacheBufSize = strlen(cacheBuf);  // TODO: can we just use len?
+		cacheBufSize = (int)strlen(cacheBuf);  // TODO: can we just use len?
 		cacheTestament = testmt;
 		cacheBufIdx = ulBuffNum;
 	}	
@@ -315,12 +314,12 @@ void zVerse::doSetText(char testmt, long idxoff, const char *buf, long len) {
 
 	__u32 start;
 	__u16 size;
-	__u32 outBufIdx = cacheBufIdx;
+	__u32 outBufIdx = (__u32)cacheBufIdx;
 
 	idxoff *= 10;
 	size = len;
 
-	start = strlen(cacheBuf);
+	start = (__u32)strlen(cacheBuf);
 
 	if (!size)
 		start = outBufIdx = 0;
@@ -344,9 +343,9 @@ void zVerse::flushCache() const {
 		__u32 size, outsize;
 		__u32 zsize, outzsize;
 
-		idxoff = cacheBufIdx * 12;
+		idxoff = (__u32)cacheBufIdx * 12;
 		if (cacheBuf) {
-			size = outsize = zsize = outzsize = strlen(cacheBuf);
+			size = outsize = zsize = outzsize = (__u32)strlen(cacheBuf);
 			if (size) {
 	//			if (compressor) {
 	//				delete compressor;
@@ -355,16 +354,16 @@ void zVerse::flushCache() const {
 				compressor->Buf(cacheBuf);
 				unsigned long tmpSize;
 				compressor->zBuf(&tmpSize);
-				outzsize = zsize = tmpSize;
+				outzsize = zsize = (__u32)tmpSize;
 
 				SWBuf buf;
 				buf.setSize(zsize + 5);
 				memcpy(buf.getRawData(), compressor->zBuf(&tmpSize), tmpSize);
-				outzsize = zsize = tmpSize;
+				outzsize = zsize = (__u32)tmpSize;
 				buf.setSize(zsize);
 				rawZFilter(buf, 1); // 1 = encipher
 
-				start = outstart = textfp[cacheTestament-1]->seek(0, SEEK_END);
+				start = outstart = (__u32)textfp[cacheTestament-1]->seek(0, SEEK_END);
 
 				outstart  = archtosword32(start);
 				outsize   = archtosword32(size);
@@ -428,7 +427,11 @@ char zVerse::createModule(const char *ipath, int blockBound, const char *v11n)
 {
 	char *path = 0;
 	char *buf = new char [ strlen (ipath) + 20 ];
+	char retVal = 0;
 	FileDesc *fd, *fd2;
+	__s32 offset = 0;
+	__s16 size = 0;
+	VerseKey vk;
 
 	stdstr(&path, ipath);
 
@@ -438,69 +441,81 @@ char zVerse::createModule(const char *ipath, int blockBound, const char *v11n)
 	sprintf(buf, "%s/ot.%czs", path, uniqueIndexID[blockBound]);
 	FileMgr::removeFile(buf);
 	fd = FileMgr::getSystemFileMgr()->open(buf, FileMgr::CREAT|FileMgr::WRONLY, FileMgr::IREAD|FileMgr::IWRITE);
-	fd->getFd();
+	if (fd->getFd() < 1) goto erroropen1;
 	FileMgr::getSystemFileMgr()->close(fd);
 
 	sprintf(buf, "%s/nt.%czs", path, uniqueIndexID[blockBound]);
 	FileMgr::removeFile(buf);
 	fd = FileMgr::getSystemFileMgr()->open(buf, FileMgr::CREAT|FileMgr::WRONLY, FileMgr::IREAD|FileMgr::IWRITE);
-	fd->getFd();
+	if (fd->getFd() < 1) goto erroropen1;
 	FileMgr::getSystemFileMgr()->close(fd);
 
 	sprintf(buf, "%s/ot.%czz", path, uniqueIndexID[blockBound]);
 	FileMgr::removeFile(buf);
 	fd = FileMgr::getSystemFileMgr()->open(buf, FileMgr::CREAT|FileMgr::WRONLY, FileMgr::IREAD|FileMgr::IWRITE);
-	fd->getFd();
+	if (fd->getFd() < 1) goto erroropen1;
 	FileMgr::getSystemFileMgr()->close(fd);
 
 	sprintf(buf, "%s/nt.%czz", path, uniqueIndexID[blockBound]);
 	FileMgr::removeFile(buf);
-	fd2 = FileMgr::getSystemFileMgr()->open(buf, FileMgr::CREAT|FileMgr::WRONLY, FileMgr::IREAD|FileMgr::IWRITE);
-	fd2->getFd();
+	fd = FileMgr::getSystemFileMgr()->open(buf, FileMgr::CREAT|FileMgr::WRONLY, FileMgr::IREAD|FileMgr::IWRITE);
+	if (fd->getFd() < 1) goto erroropen1;
 	FileMgr::getSystemFileMgr()->close(fd);
 
 	sprintf(buf, "%s/ot.%czv", path, uniqueIndexID[blockBound]);
 	FileMgr::removeFile(buf);
 	fd = FileMgr::getSystemFileMgr()->open(buf, FileMgr::CREAT|FileMgr::WRONLY, FileMgr::IREAD|FileMgr::IWRITE);
-	fd->getFd();
+	if (fd->getFd() < 1) goto erroropen1;
 
 	sprintf(buf, "%s/nt.%czv", path, uniqueIndexID[blockBound]);
 	FileMgr::removeFile(buf);
 	fd2 = FileMgr::getSystemFileMgr()->open(buf, FileMgr::CREAT|FileMgr::WRONLY, FileMgr::IREAD|FileMgr::IWRITE);
-	fd2->getFd();
+	if (fd2->getFd() < 1) goto erroropen2;
 
-	VerseKey vk;
 	vk.setVersificationSystem(v11n);
 	vk.setIntros(true);
 
-	__s32 offset = 0;
-	__s16 size = 0;
 	offset = archtosword32(offset);
 	size   = archtosword16(size);
 
 	for (vk = TOP; !vk.popError(); vk++) {
 		if (vk.getTestament() < 2) {
-			fd->write(&offset, 4);	//compBufIdxOffset
-			fd->write(&offset, 4);
-			fd->write(&size, 2);
+			if (fd->write(&offset, 4) != 4) goto writefailure;	//compBufIdxOffset
+			if (fd->write(&offset, 4) != 4) goto writefailure;
+			if (fd->write(&size, 2) != 2) goto writefailure;
 		}
 		else {
-			fd2->write(&offset, 4);	//compBufIdxOffset
-			fd2->write(&offset, 4);
-			fd2->write(&size, 2);
+			if (fd2->write(&offset, 4) != 4) goto writefailure;	//compBufIdxOffset
+			if (fd2->write(&offset, 4) != 4) goto writefailure;
+			if (fd2->write(&size, 2) != 2) goto writefailure;
 		}
 	}
 	fd2->write(&offset, 4);	//compBufIdxOffset
 	fd2->write(&offset, 4);
 	fd2->write(&size, 2);
 
-	FileMgr::getSystemFileMgr()->close(fd);
+	goto cleanup;
+
+erroropen1:
+	retVal = -1;
+	goto cleanup1;
+
+erroropen2:
+	retVal = -1;
+	goto cleanup;
+
+writefailure:
+	retVal = -2;
+
+cleanup:
 	FileMgr::getSystemFileMgr()->close(fd2);
+cleanup1:
+	FileMgr::getSystemFileMgr()->close(fd);
 
 	delete [] path;
 	delete [] buf;
 	
-	return 0;
+	return retVal;
 }
 
 
