@@ -2,7 +2,7 @@
  *
  *  osishtmlhref.cpp -	OSIS to HTML with hrefs filter
  * 
- * $Id: osishtmlhref.cpp 3173 2014-04-17 04:20:33Z greg.hellings $
+ * $Id: osishtmlhref.cpp 3548 2017-12-10 05:11:38Z scribe $
  *
  * Copyright 2003-2014 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -117,14 +117,12 @@ OSISHTMLHREF::MyUserData::MyUserData(const SWModule *module, const SWKey *key) :
 	tagStacks = new TagStacks();
 	wordsOfChristStart = "<font color=\"red\"> ";
 	wordsOfChristEnd   = "</font> ";
+	osisQToTick = true;	// default
+	isBiblicalText = false;
 	if (module) {
 		osisQToTick = ((!module->getConfigEntry("OSISqToTick")) || (strcmp(module->getConfigEntry("OSISqToTick"), "false")));
 		version = module->getName();
-		BiblicalText = (!strcmp(module->getType(), "Biblical Texts"));
-	}
-	else {
-		osisQToTick = true;	// default
-		version = "";
+		isBiblicalText = (!strcmp(module->getType(), "Biblical Texts"));
 	}
 }
 
@@ -201,9 +199,9 @@ bool OSISHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserDat
 					
 					outText("<ruby><rb>", buf, u);
 					outText(lastText, buf, u);
+					outText("</rb><rp>(</rp><rt>", buf, u);
 					val = strchr(attrib, ':');
 					val = (val) ? (val + 1) : attrib;
-					outText("</rb><rp>(</rp><rt>", buf, u);
 					outText(val, buf, u);
 					outText("</rt><rp>)</rp></ruby>", buf, u);
 				}
@@ -241,22 +239,15 @@ bool OSISHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserDat
 					if (!strongsMarkup) {	// leave strong's markup notes out, in the future we'll probably have different option filters to turn different note types on or off
 						SWBuf footnoteNumber = tag.getAttribute("swordFootnote");
 						SWBuf noteName = tag.getAttribute("n");
-						VerseKey *vkey = NULL;
 						char ch = ((tag.getAttribute("type") && ((!strcmp(tag.getAttribute("type"), "crossReference")) || (!strcmp(tag.getAttribute("type"), "x-cross-ref")))) ? 'x':'n');
 
 						u->inXRefNote = true; // Why this change? Ben Morgan: Any note can have references in, so we need to set this to true for all notes
 //						u->inXRefNote = (ch == 'x');
-
-						// see if we have a VerseKey * or descendant
-						SWTRY {
-							vkey = SWDYNAMIC_CAST(VerseKey, u->key);
-						}
-						SWCATCH ( ... ) {	}
 						buf.appendFormatted("<a href=\"passagestudy.jsp?action=showNote&type=%c&value=%s&module=%s&passage=%s\"><small><sup class=\"%c\">*%c%s</sup></small></a>",
 						        ch, 
 							URL::encode(footnoteNumber.c_str()).c_str(), 
 							URL::encode(u->version.c_str()).c_str(), 
-							URL::encode(vkey ? vkey->getText() : u->key->getText()).c_str(), 
+							URL::encode(u->vkey ? u->vkey->getText() : u->key->getText()).c_str(), 
 							ch,
 							ch, 
 							(renderNoteNumbers ? noteName.c_str() : ""));
@@ -267,7 +258,7 @@ bool OSISHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserDat
 			if (tag.isEndTag()) {
 				u->suspendTextPassThru = (--u->suspendLevel);
 				u->inXRefNote = false;
-				u->lastSuspendSegment = ""; // fix/work-around for nasb devineName in note bug
+				u->lastSuspendSegment = ""; // fix/work-around for nasb divineName in note bug
 			}
 		}
 
@@ -322,7 +313,7 @@ bool OSISHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserDat
 						// Compensate for starting :
 						ref = the_ref + 1;
 
-						int size = target.size() - ref.size() - 1;
+						int size = (int)(target.size() - ref.size() - 1);
 						work.setSize(size);
 						strncpy(work.getRawData(), target, size);
 
@@ -460,7 +451,7 @@ bool OSISHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserDat
 
 					const unsigned char *tmpBuf = (const unsigned char *)lastText.c_str();
 					getUniCharFromUTF8(&tmpBuf);
-					int char_length = (tmpBuf - (const unsigned char *)lastText.c_str());
+					int char_length = (int)(tmpBuf - (const unsigned char *)lastText.c_str());
 					scratch.setFormatted("%.*s<font size=\"-1\">%s</font>", 
 						char_length, 
 						lastText.c_str(),
@@ -509,7 +500,7 @@ bool OSISHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserDat
 				else if (type == "ol") {
 					outText("</span>", buf, u);
 				}
-				else if (type == "sup") {
+				else if (type == "super") {
 					outText("</sup>", buf, u);
 				}
 				else if (type == "sub") {
@@ -595,7 +586,7 @@ bool OSISHTMLHREF::handleToken(SWBuf &buf, const char *token, BasicFilterUserDat
 				if ((type == "added") || (type == "supplied"))
 					outText("<i>", buf, u);
 				else if (type == "tenseChange")
-					buf += "*";
+					outText( "*", buf, u);
 			}
 			else if (tag.isEndTag()) {
 				SWBuf type = u->lastTransChange;
