@@ -2,7 +2,7 @@
  *
  *  osisxhtml.cpp -	Render filter for classed XHTML of an OSIS module
  *
- * $Id: osisxhtml.cpp 3290 2014-12-04 04:54:52Z greg.hellings $
+ * $Id: osisxhtml.cpp 3548 2017-12-10 05:11:38Z scribe $
  *
  * Copyright 2011-2014 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -37,15 +37,25 @@ const char *OSISXHTML::getHeader() const {
 	const static char *header = "\
 		.divineName { font-variant: small-caps; }\n\
 		.wordsOfJesus { color: red; }\n\
-		.transChangeSupplied { font-style: italic; }\n\
-		.overline        { text-decoration: overline; }\n\
-		.indent1         { margin-left: 10px }\n\
-		.indent2         { margin-left: 20px }\n\
-		.indent3         { margin-left: 30px }\n\
-		.indent4         { margin-left: 40px }\n\
+		.transChange { font-style: italic; }\n\
+		.transChange.transChange-supplied { font-style: italic; }\n\
+		.transChange.transChange-added { font-style: italic; }\n\
+		.transChange.transChange-tenseChange::before { content: '*'; }\n\
+		.transChange.transChange-tenseChange { font-style: normal; }\n\
+		.transChange:lang(zh) { font-style: normal; text-decoration: dotted underline; }\n\
+		.overline { text-decoration: overline; }\n\
+		.indent1 { margin-left: 1em; }\n\
+		.indent2 { margin-left: 2em; }\n\
+		.indent3 { margin-left: 3em; }\n\
+		.indent4 { margin-left: 4em; }\n\
+		abbr { &:hover{ &:before{ content: attr(title); } } }\n\
 		.small-caps { font-variant: small-caps; }\n\
 		.selah { text-align: right; width: 50%; margin: 0; padding: 0; }\n\
 		.acrostic { text-align: center; }\n\
+		.colophon {font-style: italic; font-size: small; display: block; }\n\
+		.rdg { font-style: italic; }\n\
+		.catchWord {font-style: bold; }\n\
+		.x-p-indent {text-indent: 1em; }\n\
 	";
 	// Acrostic for things like the titles in Psalm 119
 	return header;
@@ -67,14 +77,19 @@ void processLemma(bool suspendTextPassThru, XMLTag &tag, SWBuf &buf) {
 		int i = (count > 1) ? 0 : -1;		// -1 for whole value cuz it's faster, but does the same thing as 0
 		do {
 			attrib = tag.getAttribute("lemma", i, ' ');
+			SWBuf at = attrib;
+			const char *prefix = at.stripPrefix(':');
 			if (i < 0) i = 0;	// to handle our -1 condition
 			val = strchr(attrib, ':');
 			val = (val) ? (val + 1) : attrib;
 			SWBuf gh;
-			if(*val == 'G')
+			if (*val == 'G') {
 				gh = "Greek";
-			if(*val == 'H')
+			}
+			else if (*val == 'H') {
 				gh = "Hebrew";
+			}
+			else if (prefix) gh = prefix;
 			const char *val2 = val;
 			if ((strchr("GH", *val)) && (isdigit(val[1])))
 				val2++;
@@ -82,7 +97,7 @@ void processLemma(bool suspendTextPassThru, XMLTag &tag, SWBuf &buf) {
 			//	show = false;
 			//else {
 				if (!suspendTextPassThru) {
-					buf.appendFormatted("<small><em class=\"strongs\">&lt;<a href=\"passagestudy.jsp?action=showStrongs&type=%s&value=%s\" class=\"strongs\">%s</a>&gt;</em></small>",
+					buf.appendFormatted("<small><em class=\"strongs\">&lt;<a class=\"strongs\" href=\"passagestudy.jsp?action=showStrongs&type=%s&value=%s\" class=\"strongs\">%s</a>&gt;</em></small>",
 							(gh.length()) ? gh.c_str() : "", 
 							URL::encode(val2).c_str(),
 							val2);
@@ -114,7 +129,7 @@ void processMorph(bool suspendTextPassThru, XMLTag &tag, SWBuf &buf) {
 				if ((*val == 'T') && (strchr("GH", val[1])) && (isdigit(val[2])))
 					val2+=2;
 				if (!suspendTextPassThru) {
-					buf.appendFormatted("<small><em class=\"morph\">(<a href=\"passagestudy.jsp?action=showMorph&type=%s&value=%s\" class=\"morph\">%s</a>)</em></small>",
+					buf.appendFormatted("<small><em class=\"morph\">(<a class=\"morph\" href=\"passagestudy.jsp?action=showMorph&type=%s&value=%s\" class=\"morph\">%s</a>)</em></small>",
 							URL::encode(tag.getAttribute("morph")).c_str(),
 							URL::encode(val).c_str(), 
 							val2);
@@ -165,18 +180,16 @@ OSISXHTML::MyUserData::MyUserData(const SWModule *module, const SWKey *key) : Ba
 	suspendLevel = 0;
 	wordsOfChristStart = "<span class=\"wordsOfJesus\"> ";
 	wordsOfChristEnd   = "</span> ";
-	interModuleLinkStart = "<a href=\"sword://%s/%s\">";
+	interModuleLinkStart = "<a class=\"%s\" href=\"sword://%s/%s\">";
 	interModuleLinkEnd = "</a>";
+	isBiblicalText = false;
+	osisQToTick = true;	// default
+	consecutiveNewlines = 0;
 	if (module) {
 		osisQToTick = ((!module->getConfigEntry("OSISqToTick")) || (strcmp(module->getConfigEntry("OSISqToTick"), "false")));
 		version = module->getName();
-		BiblicalText = (!strcmp(module->getType(), "Biblical Texts"));
+		isBiblicalText = (!strcmp(module->getType(), "Biblical Texts"));
 	}
-	else {
-		osisQToTick = true;	// default
-		version = "";
-	}
-	consecutiveNewlines = 0;
 }
 
 OSISXHTML::MyUserData::~MyUserData() {
@@ -186,9 +199,17 @@ OSISXHTML::MyUserData::~MyUserData() {
 	delete lineStack;
 }
 
+
 void OSISXHTML::MyUserData::outputNewline(SWBuf &buf) {
 	if (++consecutiveNewlines <= 2) {
-		outText("<br />\n", buf, this);
+		// any newlines at the start of a verse should get appended to a preverse heading
+		// since preverse cause a newline, simply be sure we have a preverse
+		if (!buf.size() && vkey && vkey->getVerse() && module && module->isProcessEntryAttributes()) {
+			module->getEntryAttributes()["Heading"]["Preverse"]["0"] += "<div></div>";
+		}
+		else {
+			outText("<br />\n", buf, this);
+		}
 		supressAdjacentWhitespace = true;
 	}
 }
@@ -235,9 +256,9 @@ bool OSISXHTML::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 					
 					outText("<ruby><rb>", buf, u);
 					outText(lastText, buf, u);
+					outText("</rb><rp>(</rp><rt>", buf, u);
 					val = strchr(attrib, ':');
 					val = (val) ? (val + 1) : attrib;
-					outText("</rb><rp>(</rp><rt>", buf, u);
 					outText(val, buf, u);
 					outText("</rt><rp>)</rp></ruby>", buf, u);
 				}
@@ -257,7 +278,7 @@ bool OSISXHTML::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 				}
 
 				/*if (endTag)
-					buf += "}";*/
+					outText( "}", buf, u);*/
 			}
 		}
 
@@ -265,6 +286,16 @@ bool OSISXHTML::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 		else if (!strcmp(tag.getName(), "note")) {
 			if (!tag.isEndTag()) {
 				SWBuf type = tag.getAttribute("type");
+				SWBuf subType = tag.getAttribute("subType");
+				SWBuf classExtras = "";
+
+				if (type.size()) {
+					classExtras.append(" ").append(type);
+				}
+				if (subType.size()) {
+                                        classExtras.append(" ").append(subType);
+                                }
+
 				bool strongsMarkup = (type == "x-strongsMarkup" || type == "strongsMarkup");	// the latter is deprecated
 				if (strongsMarkup) {
 					tag.setEmpty(false);	// handle bug in KJV2003 module where some note open tags were <note ... />
@@ -275,30 +306,26 @@ bool OSISXHTML::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 					if (!strongsMarkup) {	// leave strong's markup notes out, in the future we'll probably have different option filters to turn different note types on or off
 						SWBuf footnoteNumber = tag.getAttribute("swordFootnote");
 						SWBuf noteName = tag.getAttribute("n");
-						VerseKey *vkey = NULL;
 						char ch = ((tag.getAttribute("type") && ((!strcmp(tag.getAttribute("type"), "crossReference")) || (!strcmp(tag.getAttribute("type"), "x-cross-ref")))) ? 'x':'n');
 
 						u->inXRefNote = true; // Why this change? Ben Morgan: Any note can have references in, so we need to set this to true for all notes
 //						u->inXRefNote = (ch == 'x');
 
-						// see if we have a VerseKey * or descendant
-						SWTRY {
-							vkey = SWDYNAMIC_CAST(VerseKey, u->key);
-						}
-						SWCATCH ( ... ) {	}
-						if (vkey) {
-							//printf("URL = %s\n",URL::encode(vkey->getText()).c_str());
-							buf.appendFormatted("<a href=\"passagestudy.jsp?action=showNote&type=%c&value=%s&module=%s&passage=%s\"><small><sup class=\"%c\">*%c%s</sup></small></a>",
+						if (u->vkey) {
+							//printf("URL = %s\n",URL::encode(u->vkey->getText()).c_str());
+							buf.appendFormatted("<a class=\"%s\" href=\"passagestudy.jsp?action=showNote&type=%c&value=%s&module=%s&passage=%s\"><small><sup class=\"%c\">*%c%s</sup></small></a>",
+								classExtras.c_str(),
 								ch, 
 								URL::encode(footnoteNumber.c_str()).c_str(), 
 								URL::encode(u->version.c_str()).c_str(), 
-								URL::encode(vkey->getText()).c_str(), 
+								URL::encode(u->vkey->getText()).c_str(), 
 								ch,
 								ch, 
 								(renderNoteNumbers ? noteName.c_str() : ""));
 						}
 						else {
-							buf.appendFormatted("<a href=\"passagestudy.jsp?action=showNote&type=%c&value=%s&module=%s&passage=%s\"><small><sup class=\"%c\">*%c%s</sup></small></a>",
+							buf.appendFormatted("<a class=\"%s\" href=\"passagestudy.jsp?action=showNote&type=%c&value=%s&module=%s&passage=%s\"><small><sup class=\"%c\">*%c%s</sup></small></a>",
+								classExtras.c_str(),
 								ch, 
 								URL::encode(footnoteNumber.c_str()).c_str(), 
 								URL::encode(u->version.c_str()).c_str(), 
@@ -314,11 +341,11 @@ bool OSISXHTML::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 			if (tag.isEndTag()) {
 				u->suspendTextPassThru = (--u->suspendLevel);
 				u->inXRefNote = false;
-				u->lastSuspendSegment = ""; // fix/work-around for nasb devineName in note bug
+				u->lastSuspendSegment = ""; // fix/work-around for nasb divineName in note bug
 			}
 		}
 
-		// <p> paragraph and <lg> linegroup tags
+		// <p> paragraph and <lg> linegroup tags except newline at start of verse (immediately after verse number)
 		else if (!strcmp(tag.getName(), "p") || !strcmp(tag.getName(), "lg")) {
 			if ((!tag.isEndTag()) && (!tag.isEmpty())) {	// non-empty start tag
 				u->outputNewline(buf);
@@ -334,14 +361,24 @@ bool OSISXHTML::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 		// Milestoned paragraphs, created by osis2mod
 		// <div type="paragraph" sID.../>
 		// <div type="paragraph" eID.../>
-		else if (tag.isEmpty() && !strcmp(tag.getName(), "div") && tag.getAttribute("type") && (!strcmp(tag.getAttribute("type"), "x-p") || !strcmp(tag.getAttribute("type"), "paragraph"))) {
+		else if (tag.isEmpty() && !strcmp(tag.getName(), "div") && tag.getAttribute("type") && (!strcmp(tag.getAttribute("type"), "x-p") || !strcmp(tag.getAttribute("type"), "paragraph") || !strcmp(tag.getAttribute("type"), "colophon"))) {
 			// <div type="paragraph"  sID... />
 			if (tag.getAttribute("sID")) {	// non-empty start tag
 				u->outputNewline(buf);
+				// safe because we've verified type is present from if statement above
+				if (!strcmp(tag.getAttribute("type"), "colophon")) {
+					outText("<div class=\"colophon\">", buf, u);
+				}
+				
 			}
 			// <div type="paragraph"  eID... />
 			else if (tag.getAttribute("eID")) {
 				u->outputNewline(buf);
+				// safe because we've verified type is present from if statement above
+				if (!strcmp(tag.getAttribute("type"), "colophon")) {
+					outText("</div>", buf, u);
+				}
+				
 			}
 		}
 
@@ -352,10 +389,18 @@ bool OSISXHTML::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 					SWBuf target;
 					SWBuf work;
 					SWBuf ref;
+					SWBuf type;
+					SWBuf classes = "";
+					
 					bool is_scripRef = false;
 
 					target = tag.getAttribute("osisRef");
 					const char* the_ref = strchr(target, ':');
+					type = tag.getAttribute("type");
+					
+					if (type.size()) {
+						classes.append(type);
+					}
 					
 					if(!the_ref) {
 						// No work
@@ -377,7 +422,8 @@ bool OSISXHTML::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 
 					if(is_scripRef)
 					{
-						buf.appendFormatted("<a href=\"passagestudy.jsp?action=showRef&type=scripRef&value=%s&module=\">",
+						buf.appendFormatted("<a class=\"%s\" href=\"passagestudy.jsp?action=showRef&type=scripRef&value=%s&module=\">",
+							classes.c_str(),
 							URL::encode(ref.c_str()).c_str()
 //							(work.size()) ? URL::encode(work.c_str()).c_str() : "")
 							);
@@ -385,7 +431,8 @@ bool OSISXHTML::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 					else
 					{
 						// Dictionary link, or something
-						buf.appendFormatted(u->interModuleLinkStart, 
+						buf.appendFormatted(u->interModuleLinkStart,
+							classes.c_str(), 
 							URL::encode(work.c_str()).c_str(),
 							URL::encode(ref.c_str()).c_str()
 							);
@@ -440,18 +487,20 @@ bool OSISXHTML::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 		// <milestone type="x-p"/>
 		// <milestone type="cQuote" marker="x"/>
 		else if ((!strcmp(tag.getName(), "milestone")) && (tag.getAttribute("type"))) {
-			if (!strcmp(tag.getAttribute("type"), "line")) {
+			// safe because we've verified type is present from if statement above
+			const char *type = tag.getAttribute("type");
+			if (!strcmp(type, "line")) {
 				u->outputNewline(buf);
 				if (tag.getAttribute("subType") && !strcmp(tag.getAttribute("subType"), "x-PM")) {
 					u->outputNewline(buf);
 				}
 			}
-			else if (!strcmp(tag.getAttribute("type"),"x-p"))  {
+			else if (!strcmp(type,"x-p"))  {
 				if (tag.getAttribute("marker"))
 					outText(tag.getAttribute("marker"), buf, u);
 				else outText("<!p>", buf, u);
 			}
-			else if (!strcmp(tag.getAttribute("type"), "cQuote")) {
+			else if (!strcmp(type, "cQuote")) {
 				const char *tmp = tag.getAttribute("marker");
 				bool hasMark    = tmp;
 				SWBuf mark      = tmp;
@@ -465,41 +514,55 @@ bool OSISXHTML::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 				else if (u->osisQToTick)
 					outText((level % 2) ? '\"' : '\'', buf, u);
 			}
+			else if (!strcmp(type, "x-importer")) {
+				//drop tag as not relevant
+			} 
+			
+			
+			else {
+				SWBuf type = tag.getAttribute("type");
+				outText(SWBuf("<span class=\"") + type + "\"/>", buf,u);
+			}
 		}
 
 		// <title>
 		else if (!strcmp(tag.getName(), "title")) {
 			if ((!tag.isEndTag()) && (!tag.isEmpty())) {
 				SWBuf type = tag.getAttribute("type");
-				bool keepType = false;
+				SWBuf canonical = tag.getAttribute("canonical");
+				
+				SWBuf classExtras = "";
+
 				if (type.size()) {
-					keepType = true;
+					classExtras.append(" ").append(type);
 				}
-				VerseKey *vkey = SWDYNAMIC_CAST(VerseKey, u->key);
-				if (vkey && !vkey->getVerse()) {
-					if (!vkey->getChapter()) {
-						if (!vkey->getBook()) {
-							if (!vkey->getTestament()) {
-								buf += SWBuf("<h1 class=\"moduleHeader ") + (keepType ? type : "") + "\">";
+				if (canonical.size() && !strcmp(canonical,"true")) {
+					classExtras.append(" canonical");
+				} 
+				if (u->vkey && !u->vkey->getVerse()) {
+					if (!u->vkey->getChapter()) {
+						if (!u->vkey->getBook()) {
+							if (!u->vkey->getTestament()) {
+								outText(SWBuf("<h1 class=\"moduleHeader") + classExtras + "\">",  buf, u);
 								tag.setAttribute("pushed", "h1");
 							}
 							else {
-								buf += SWBuf("<h1 class=\"testamentHeader ") + (keepType ? type : "") + "\">";
+								outText(SWBuf("<h1 class=\"testamentHeader") + classExtras + "\">", buf, u);
 								tag.setAttribute("pushed", "h1");
 							}
 						}
 						else {
-							buf += SWBuf("<h1 class=\"bookHeader ") + (keepType ? type : "") + "\">";
+							outText(SWBuf("<h1 class=\"bookHeader") + classExtras + "\">", buf, u);
 							tag.setAttribute("pushed", "h1");
 						}
 					}
 					else {
-						buf += SWBuf("<h2 class=\"chapterHeader ") + (keepType ? type : "") + "\">";
+						outText(SWBuf("<h2 class=\"chapterHeader") + classExtras + "\">", buf, u);
 						tag.setAttribute("pushed", "h2");
 					}
 				}
 				else {
-					buf += SWBuf("<h3 class=\"") + (keepType ? type : "") + "\">";
+					outText(SWBuf("<h3 class=\"title") + classExtras + "\">", buf, u);
 					tag.setAttribute("pushed", "h3");
 				}
 				u->titleStack->push(tag.toString());
@@ -510,10 +573,10 @@ bool OSISXHTML::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 					if (u->titleStack->size()) u->titleStack->pop();
 					SWBuf pushed = tag.getAttribute("pushed");
 					if (pushed.size()) {
-						buf += (SWBuf)"</" + pushed + ">\n\n";
+						outText((SWBuf)"</" + pushed + ">\n\n", buf, u);
 					}
 					else {
-						buf += "</h3>\n\n";
+						outText( "</h3>\n\n", buf, u);
 					}
 					++u->consecutiveNewlines;
 					u->supressAdjacentWhitespace = true;
@@ -547,10 +610,12 @@ bool OSISXHTML::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 		// <catchWord> & <rdg> tags (italicize)
 		else if (!strcmp(tag.getName(), "rdg") || !strcmp(tag.getName(), "catchWord")) {
 			if ((!tag.isEndTag()) && (!tag.isEmpty())) {
-				outText("<i>", buf, u);
+				outText("<span class=\"", buf, u);
+				outText(tag.getName(), buf, u);
+				outText("\">", buf, u);
 			}
 			else if (tag.isEndTag()) {
-				outText("</i>", buf, u);
+				outText("</span>", buf, u);
 			}
 		}
 
@@ -617,7 +682,7 @@ bool OSISXHTML::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 				else if (type == "ol") {
 					outText("</span>", buf, u);
 				}
-				else if (type == "sup") {
+				else if (type == "super") {
 					outText("</sup>", buf, u);
 				}
 				else if (type == "sub") {
@@ -700,17 +765,16 @@ bool OSISXHTML::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 			if ((!tag.isEndTag()) && (!tag.isEmpty())) {
 				SWBuf type = tag.getAttribute("type");
 				u->lastTransChange = type;
-
-				// just do all transChange tags this way for now
-				if ((type == "added") || (type == "supplied"))
-					outText("<span class=\"transChangeSupplied\">", buf, u);
-				else if (type == "tenseChange")
-					buf += "*";
+				
+				outText("<span class=\"transChange", buf, u);
+				if (type.length()) {
+					outText(" transChange-", buf, u);
+					outText(type, buf, u);
+				}
+				outText("\">", buf, u);
 			}
 			else if (tag.isEndTag()) {
-				SWBuf type = u->lastTransChange;
-				if ((type == "added") || (type == "supplied"))
-					outText("</span>", buf, u);
+				outText("</span>", buf, u);
 			}
 			else {	// empty transChange marker?
 			}
@@ -754,22 +818,42 @@ bool OSISXHTML::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 			}
 			else if (type == "majorSection") {
 			}
-			else {
-				buf += tag;
+			else if ((!tag.isEndTag()) && (!tag.isEmpty())) {
+				SWBuf type = tag.getAttribute("type");
+				outText("<div class=\"", buf, u);
+				outText(type, buf, u);
+				outText("\">", buf, u);
+			     }
+			     else if (tag.isEndTag()) {
+			     	outText("</div>", buf, u);
 			}
+			else if (!(type == "colophon")) outText(tag, buf, u);
+			
 		}
 		else if (!strcmp(tag.getName(), "span")) {
-			buf += tag;
+			outText(tag, buf, u);
+		}
+		else if (!strcmp(tag.getName(), "abbr")) {
+			if (!tag.isEndTag()) {
+				SWBuf title = tag.getAttribute("expansion");
+				outText("<abbr title=\"", buf, u);
+				outText(title, buf, u); 
+				outText("\">", buf, u);
+			}
+			else if (tag.isEndTag()) {
+				outText("</abbr>", buf, u);
+			}
+		
 		}
 		else if (!strcmp(tag.getName(), "br")) {
-			buf += tag;
+			outText( tag, buf, u);
 		}
 		else if (!strcmp(tag.getName(), "table")) {
 			if ((!tag.isEndTag()) && (!tag.isEmpty())) {
-				buf += "<table><tbody>\n";
+				outText( "<table><tbody>\n", buf, u);
 			}
 			else if (tag.isEndTag()) {
-				buf += "</tbody></table>\n";
+				outText( "</tbody></table>\n", buf, u);
 				++u->consecutiveNewlines;
 				u->supressAdjacentWhitespace = true;
 			}
@@ -777,19 +861,19 @@ bool OSISXHTML::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *
 		}
 		else if (!strcmp(tag.getName(), "row")) {
 			if ((!tag.isEndTag()) && (!tag.isEmpty())) {
-				buf += "\t<tr>";
+				outText( "\t<tr>", buf, u);
 			}
 			else if (tag.isEndTag()) {
-				buf += "</tr>\n";
+				outText( "</tr>\n", buf, u);
 			}
 			
 		}
 		else if (!strcmp(tag.getName(), "cell")) {
 			if ((!tag.isEndTag()) && (!tag.isEmpty())) {
-				buf += "<td>";
+				outText( "<td>", buf, u);
 			}
 			else if (tag.isEndTag()) {
-				buf += "</td>";
+				outText( "</td>", buf, u);
 			}
 		}
 		else {
