@@ -2,7 +2,7 @@
  *
  *  rtfhtml.cpp -	filter to convert RTF to HTML
  *
- * $Id: rtfhtml.cpp 2981 2013-09-15 00:05:26Z scribe $
+ * $Id: rtfhtml.cpp 3515 2017-11-01 11:38:09Z scribe $
  *
  * Copyright 1999 The team of Bibletime (info@bibletime.de)
  * Copyright 2000-2013 CrossWire Bible Society (http://www.crosswire.org)
@@ -55,7 +55,7 @@ char RTFHTML::processText(SWBuf &text, const SWKey *key, const SWModule *module)
 				num.append(from, end-from);
 				__s16 n = atoi(num.c_str());
 				__u32 u = (__u16)n;
-				text.append(getUTF8FromUniChar(u));
+				getUTF8FromUniChar(u, &text);
 				from += (end-from);
 				continue;
 			}
