@@ -3,7 +3,7 @@
  *  thmlstrongs.cpp -	SWFilter descendant to hide or show Strong's number
  *			in a ThML module
  *
- * $Id: thmlstrongs.cpp 2980 2013-09-14 21:51:47Z scribe $
+ * $Id: thmlstrongs.cpp 3515 2017-11-01 11:38:09Z scribe $
  *
  * Copyright 2001-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -60,7 +60,7 @@ char ThMLStrongs::processText(SWBuf &text, const SWKey *key, const SWModule *mod
 	bool lastspace = false;
 	int word = 1;
 	char val[128];
-	char wordstr[5];
+	char wordstr[11];
 	char *valto;
 	char *ch;
 	unsigned int textStart = 0, textEnd = 0;
@@ -77,7 +77,7 @@ char ThMLStrongs::processText(SWBuf &text, const SWKey *key, const SWModule *mod
 			token[0] = 0;
 			token[1] = 0;
 			token[2] = 0;
-			textEnd = text.length();
+			textEnd = (unsigned int)text.length();
 			continue;
 		}
 		if (*from == '>') {	// process tokens
@@ -116,7 +116,7 @@ char ThMLStrongs::processText(SWBuf &text, const SWKey *key, const SWModule *mod
 						if (lastspace)
 							text--;
 					}
-					if (newText) {textStart = text.length(); newText = false; }
+					if (newText) {textStart = (unsigned int)text.length(); newText = false; }
 					continue;
 				}
 			}
@@ -150,15 +150,17 @@ char ThMLStrongs::processText(SWBuf &text, const SWKey *key, const SWModule *mod
 			text += '<';
 			text += token;
 			text += '>';
-			if (newText) {textStart = text.length(); newText = false; }
+			if (newText) {textStart = (unsigned int)text.length(); newText = false; }
 			continue;
 		}
 		if (intoken) {
-			if (tokpos < 2045)
+			if (tokpos < 2045) {
 				token[tokpos++] = *from;
+				// TODO: why is this + 2 ?
 				token[tokpos+2] = 0;
+			}
 		}
-		else	{
+		else {
 			text += *from;
 			lastspace = (*from == ' ');
 		}
