@@ -3,7 +3,7 @@
  *  rawld4.cpp -	code for class 'RawLD'- a module that reads raw
  *			lexicon and dictionary files: *.dat *.idx
  *
- * $Id: rawld4.cpp 2980 2013-09-14 21:51:47Z scribe $
+ * $Id: rawld4.cpp 3515 2017-11-01 11:38:09Z scribe $
  *
  * Copyright 2001-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -81,7 +81,7 @@ char RawLD4::getEntry(long away) const
 	char *buf = new char [ strlen(*key) + 6 ];
 	strcpy(buf, *key);
 
-	strongsPad(buf);
+	if (strongsPadding) strongsPad(buf);
 
 	entryBuf = "";
 	if (!(retval = findOffset(buf, &start, &size, away))) {
@@ -145,12 +145,26 @@ void RawLD4::increment(int steps) {
 
 
 void RawLD4::setEntry(const char *inbuf, long len) {
-	doSetText(*key, inbuf, len);
+	char *buf = new char [ strlen(*key) + 6 ];
+	strcpy(buf, *key);
+
+	if (strongsPadding) strongsPad(buf);
+
+	doSetText(buf, inbuf, len);
+
+	delete [] buf;
 }
 
 
 void RawLD4::linkEntry(const SWKey *inkey) {
-	doLinkEntry(*key, *inkey);
+	char *buf = new char [ strlen(*key) + 6 ];
+	strcpy(buf, *key);
+
+	if (strongsPadding) strongsPad(buf);
+
+	doLinkEntry(buf, *inkey);
+
+	delete [] buf;
 }
 
 
@@ -161,12 +175,19 @@ void RawLD4::linkEntry(const SWKey *inkey) {
  */
 
 void RawLD4::deleteEntry() {
-	doSetText(*key, "");
+	char *buf = new char [ strlen(*key) + 6 ];
+	strcpy(buf, *key);
+
+	if (strongsPadding) strongsPad(buf);
+
+	doSetText(buf, "");
+
+	delete [] buf;
 }
 
 
 long RawLD4::getEntryCount() const {
-	if (idxfd < 0) return 0;
+	if (!idxfd || idxfd->getFd() < 0) return 0;
 	return idxfd->seek(0, SEEK_END) / IDXENTRYSIZE;
 }
 
@@ -178,7 +199,7 @@ long RawLD4::getEntryForKey(const char *key) const {
 	char *buf = new char [ strlen(key) + 6 ];
 	strcpy(buf, key);
 
-	strongsPad(buf);
+	if (strongsPadding) strongsPad(buf);
 	
 	findOffset(buf, &start, &size, 0, &offset);
 
