@@ -2,7 +2,7 @@
  *
  *  roman.cpp -	
  *
- * $Id: roman.cpp 2980 2013-09-14 21:51:47Z scribe $
+ * $Id: roman.cpp 3439 2016-10-23 08:32:02Z scribe $
  *
  * Copyright 2002-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -37,7 +37,7 @@ char isroman (const char *str, int maxchars) {
 }
 
 int from_rom(const char* str) {
-	int i, n = strlen(str);
+	int i, n = (int)strlen(str);
 	short * num= (short *) calloc(n, sizeof(short));
 	for (i = 0; str[i]; i++) {
 		switch(str[i]) {
