@@ -1,5 +1,10 @@
-/*
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+/******************************************************************************
+ *
+ *  ciphertest.cpp -	
+ *
+ * $Id: ciphertest.cpp 2833 2013-06-29 06:40:28Z chrislit $
+ *
+ * Copyright 2005-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -30,7 +35,7 @@ int main(int argc, char **argv) {
 	}
 
 	
-	int encipher = atoi(argv[2]);
+	long encipher = atoi(argv[2]);
 
 	SWFilter *filter = new CipherFilter(argv[1]);
 
