@@ -1,5 +1,10 @@
-/*
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+/******************************************************************************
+ *
+ *  configtest.cpp -	
+ *
+ * $Id: configtest.cpp 3515 2017-11-01 11:38:09Z scribe $
+ *
+ * Copyright 2001-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -26,7 +31,7 @@ int main(int argc, char **argv) {
     config["Section1"]["Entry1"] = "Value1";
     config["Section1"]["Entry2"] = "oops";
     config["Section1"]["Entry2"] = "Value2";
-    config.Save();
+    config.save();
     SWConfig config2("./test1.conf");
     std::cout << "Should be Value2: " << config2["Section1"]["Entry2"] << std::endl;
     return 0;
