@@ -1,5 +1,10 @@
-/*
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+/******************************************************************************
+ *
+ *  indextest.cpp -	
+ *
+ * $Id: indextest.cpp 2833 2013-06-29 06:40:28Z chrislit $
+ *
+ * Copyright 2000-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -30,10 +35,10 @@ int main(int argc, char **argv) {
 
 	if (bbe) {
 		VerseKey vk;
-		vk.Persist(1);
+		vk.setPersist(true);
 		bbe->setKey(vk);
-		for (; !bbe->Error(); (*bbe)++ ) {
-			std::cout << vk.Index() << std::endl; 
+		for (; !bbe->popError(); (*bbe)++ ) {
+			std::cout << vk.getIndex() << std::endl; 
 		}
 	}
 	return 0;
