@@ -3,7 +3,7 @@
 #  usrinst.sh -	Convenience script specifying most common development options
 #		to ./configure
 #
-# $Id: usrinst.sh 3164 2014-04-17 04:06:51Z greg.hellings $
+# $Id: usrinst.sh 3472 2017-05-22 04:19:02Z scribe $
 #
 # Copyright 2002-2013 CrossWire Bible Society (http://www.crosswire.org)
 #	CrossWire Bible Society
@@ -35,6 +35,7 @@ OPTIONS="--enable-debug $OPTIONS"
 #OPTIONS="--enable-profile $OPTIONS"
 
 #OPTIONS="--with-cxx11regex $OPTIONS"
+OPTIONS="--with-icuregex $OPTIONS"
 #OPTIONS="--with-icusword $OPTIONS"
 #OPTIONS="--without-icu $OPTIONS"
 #OPTIONS="--without-clucene $OPTIONS"
@@ -48,6 +49,25 @@ OPTIONS="--enable-debug $OPTIONS"
 #LIBS="-no-undefined"
 #OPTIONS="lt_cv_deplibs_check_method=pass_all $OPTIONS"
 
+# These are for experimental purposes, review,
+# may not be available on all platforms, are unsupported,
+# and no modules should be released which depend on them. 
+# If significant gains in size and speed are achieved,
+# we should discuss the portability of these libraries
+# and decide if we should make the switch to prefer one
+# of these compression systems over zlib.
+# That's not to say that support for these is not appreciated
+# (chrislit)-- on the contrary, this is the R in R&D, we just
+# need to consider portability: ios, android-ndk, and
+# windows support, before implying modules can be made with them.
+# I am all for switching to one, by policy, if we observe appreciable
+# gains and confirm portability.  I only see support disadvantages to
+# expanding compression options, otherwise.
+
+#OPTIONS="--with-bzip2 $OPTIONS"
+#OPTIONS="--with-xz $OPTIONS"
+
+
 LIBS="$LIBS" ./configure $OPTIONS $*
 
 
