@@ -2,7 +2,7 @@
  *
  *  diafiltmgr.h -	DiathekeFilterMgr
  *
- * $Id: diafiltmgr.h 2833 2013-06-29 06:40:28Z chrislit $
+ * $Id: diafiltmgr.h 3113 2014-03-12 12:42:07Z chrislit $
  *
  * Copyright 2001-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -24,6 +24,7 @@
 #define DIAFILTMGR_H
 
 #define FMT_CGI 127
+#define FMT_INTERNAL 126
 
 #include <encfiltmgr.h>
 
@@ -37,6 +38,7 @@ protected:
         SWFilter* fromgbf;
         SWFilter* fromplain;
         SWFilter* fromosis;
+        SWFilter* fromtei;
 
         char markup;
 
