@@ -2,7 +2,7 @@
  *
  *  diathekemgr.h -	DiathekeMgr
  *
- * $Id: diathekemgr.h 2833 2013-06-29 06:40:28Z chrislit $
+ * $Id: diathekemgr.h 3515 2017-11-01 11:38:09Z scribe $
  *
  * Copyright 2001-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
@@ -38,9 +38,9 @@ class DiathekeMgr : public SWMgr {
 #endif
 
 protected:
-	virtual void AddRenderFilters(SWModule *module, ConfigEntMap &section);
-	virtual signed char Load ();
-	virtual void AddGlobalOptions (SWModule * module, ConfigEntMap & section, ConfigEntMap::iterator start, ConfigEntMap::iterator end);
+	virtual void addRenderFilters(SWModule *module, ConfigEntMap &section);
+	virtual signed char load();
+	virtual void addGlobalOptionFilters(SWModule * module, ConfigEntMap & section);
 
 public:
 	bool shape;
